# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/grossmj/PycharmProjects/gns3-gui/gns3/modules/qemu/ui/qemu_vm_wizard.ui'
#
# Created: Fri Mar 13 11:09:58 2015
#      by: PyQt4 UI code generator 4.10.4
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_QemuVMWizard(object):
    def setupUi(self, QemuVMWizard):
        QemuVMWizard.setObjectName(_fromUtf8("QemuVMWizard"))
        QemuVMWizard.resize(514, 366)
        QemuVMWizard.setModal(True)
        self.uiServerWizardPage = QtGui.QWizardPage()
        self.uiServerWizardPage.setObjectName(_fromUtf8("uiServerWizardPage"))
        self.gridLayout_4 = QtGui.QGridLayout(self.uiServerWizardPage)
        self.gridLayout_4.setObjectName(_fromUtf8("gridLayout_4"))
        self.uiServerTypeGroupBox = QtGui.QGroupBox(self.uiServerWizardPage)
        self.uiServerTypeGroupBox.setObjectName(_fromUtf8("uiServerTypeGroupBox"))
        self.horizontalLayout = QtGui.QHBoxLayout(self.uiServerTypeGroupBox)
        self.horizontalLayout.setObjectName(_fromUtf8("horizontalLayout"))
        self.uiRemoteRadioButton = QtGui.QRadioButton(self.uiServerTypeGroupBox)
        self.uiRemoteRadioButton.setChecked(True)
        self.uiRemoteRadioButton.setObjectName(_fromUtf8("uiRemoteRadioButton"))
        self.horizontalLayout.addWidget(self.uiRemoteRadioButton)
        self.uiCloudRadioButton = QtGui.QRadioButton(self.uiServerTypeGroupBox)
        self.uiCloudRadioButton.setObjectName(_fromUtf8("uiCloudRadioButton"))
        self.horizontalLayout.addWidget(self.uiCloudRadioButton)
        self.uiLocalRadioButton = QtGui.QRadioButton(self.uiServerTypeGroupBox)
        self.uiLocalRadioButton.setObjectName(_fromUtf8("uiLocalRadioButton"))
        self.horizontalLayout.addWidget(self.uiLocalRadioButton)
        spacerItem = QtGui.QSpacerItem(40, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.gridLayout_4.addWidget(self.uiServerTypeGroupBox, 0, 0, 1, 1)
        self.uiRemoteServersGroupBox = QtGui.QGroupBox(self.uiServerWizardPage)
        self.uiRemoteServersGroupBox.setObjectName(_fromUtf8("uiRemoteServersGroupBox"))
        self.gridLayout_8 = QtGui.QGridLayout(self.uiRemoteServersGroupBox)
        self.gridLayout_8.setObjectName(_fromUtf8("gridLayout_8"))
        self.uiRemoteServersComboBox = QtGui.QComboBox(self.uiRemoteServersGroupBox)
        self.uiRemoteServersComboBox.setEnabled(True)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiRemoteServersComboBox.sizePolicy().hasHeightForWidth())
        self.uiRemoteServersComboBox.setSizePolicy(sizePolicy)
        self.uiRemoteServersComboBox.setObjectName(_fromUtf8("uiRemoteServersComboBox"))
        self.gridLayout_8.addWidget(self.uiRemoteServersComboBox, 0, 1, 1, 1)
        self.uiRemoteServersLabel = QtGui.QLabel(self.uiRemoteServersGroupBox)
        self.uiRemoteServersLabel.setObjectName(_fromUtf8("uiRemoteServersLabel"))
        self.gridLayout_8.addWidget(self.uiRemoteServersLabel, 0, 0, 1, 1)
        self.gridLayout_4.addWidget(self.uiRemoteServersGroupBox, 1, 0, 1, 1)
        QemuVMWizard.addPage(self.uiServerWizardPage)
        self.uiTypeWizardPage = QtGui.QWizardPage()
        self.uiTypeWizardPage.setObjectName(_fromUtf8("uiTypeWizardPage"))
        self.horizontalLayout_2 = QtGui.QHBoxLayout(self.uiTypeWizardPage)
        self.horizontalLayout_2.setObjectName(_fromUtf8("horizontalLayout_2"))
        self.uiTypeLabel = QtGui.QLabel(self.uiTypeWizardPage)
        self.uiTypeLabel.setObjectName(_fromUtf8("uiTypeLabel"))
        self.horizontalLayout_2.addWidget(self.uiTypeLabel)
        self.uiTypeComboBox = QtGui.QComboBox(self.uiTypeWizardPage)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiTypeComboBox.sizePolicy().hasHeightForWidth())
        self.uiTypeComboBox.setSizePolicy(sizePolicy)
        self.uiTypeComboBox.setObjectName(_fromUtf8("uiTypeComboBox"))
        self.horizontalLayout_2.addWidget(self.uiTypeComboBox)
        QemuVMWizard.addPage(self.uiTypeWizardPage)
        self.uiNameWizardPage = QtGui.QWizardPage()
        self.uiNameWizardPage.setObjectName(_fromUtf8("uiNameWizardPage"))
        self.gridLayout = QtGui.QGridLayout(self.uiNameWizardPage)
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.uiNameLineEdit = QtGui.QLineEdit(self.uiNameWizardPage)
        self.uiNameLineEdit.setObjectName(_fromUtf8("uiNameLineEdit"))
        self.gridLayout.addWidget(self.uiNameLineEdit, 0, 1, 1, 1)
        self.uiNameLabel = QtGui.QLabel(self.uiNameWizardPage)
        self.uiNameLabel.setObjectName(_fromUtf8("uiNameLabel"))
        self.gridLayout.addWidget(self.uiNameLabel, 0, 0, 1, 1)
        QemuVMWizard.addPage(self.uiNameWizardPage)
        self.uiBinaryMemoryWizardPage = QtGui.QWizardPage()
        self.uiBinaryMemoryWizardPage.setObjectName(_fromUtf8("uiBinaryMemoryWizardPage"))
        self.gridLayout_2 = QtGui.QGridLayout(self.uiBinaryMemoryWizardPage)
        self.gridLayout_2.setObjectName(_fromUtf8("gridLayout_2"))
        self.uiRamLabel = QtGui.QLabel(self.uiBinaryMemoryWizardPage)
        self.uiRamLabel.setObjectName(_fromUtf8("uiRamLabel"))
        self.gridLayout_2.addWidget(self.uiRamLabel, 1, 0, 1, 1)
        self.uiQemuListLabel = QtGui.QLabel(self.uiBinaryMemoryWizardPage)
        self.uiQemuListLabel.setObjectName(_fromUtf8("uiQemuListLabel"))
        self.gridLayout_2.addWidget(self.uiQemuListLabel, 0, 0, 1, 1)
        self.uiRamSpinBox = QtGui.QSpinBox(self.uiBinaryMemoryWizardPage)
        self.uiRamSpinBox.setMinimum(32)
        self.uiRamSpinBox.setMaximum(65535)
        self.uiRamSpinBox.setProperty("value", 256)
        self.uiRamSpinBox.setObjectName(_fromUtf8("uiRamSpinBox"))
        self.gridLayout_2.addWidget(self.uiRamSpinBox, 1, 1, 1, 1)
        self.uiQemuListComboBox = QtGui.QComboBox(self.uiBinaryMemoryWizardPage)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiQemuListComboBox.sizePolicy().hasHeightForWidth())
        self.uiQemuListComboBox.setSizePolicy(sizePolicy)
        self.uiQemuListComboBox.setObjectName(_fromUtf8("uiQemuListComboBox"))
        self.gridLayout_2.addWidget(self.uiQemuListComboBox, 0, 1, 1, 1)
        QemuVMWizard.addPage(self.uiBinaryMemoryWizardPage)
        self.uiDiskWizardPage = QtGui.QWizardPage()
        self.uiDiskWizardPage.setObjectName(_fromUtf8("uiDiskWizardPage"))
        self.gridLayout_6 = QtGui.QGridLayout(self.uiDiskWizardPage)
        self.gridLayout_6.setObjectName(_fromUtf8("gridLayout_6"))
        self.horizontalLayout_8 = QtGui.QHBoxLayout()
        self.horizontalLayout_8.setObjectName(_fromUtf8("horizontalLayout_8"))
        self.uiHdaDiskImageLineEdit = QtGui.QLineEdit(self.uiDiskWizardPage)
        self.uiHdaDiskImageLineEdit.setObjectName(_fromUtf8("uiHdaDiskImageLineEdit"))
        self.horizontalLayout_8.addWidget(self.uiHdaDiskImageLineEdit)
        self.uiHdaDiskImageToolButton = QtGui.QToolButton(self.uiDiskWizardPage)
        self.uiHdaDiskImageToolButton.setToolButtonStyle(QtCore.Qt.ToolButtonTextOnly)
        self.uiHdaDiskImageToolButton.setObjectName(_fromUtf8("uiHdaDiskImageToolButton"))
        self.horizontalLayout_8.addWidget(self.uiHdaDiskImageToolButton)
        self.gridLayout_6.addLayout(self.horizontalLayout_8, 0, 1, 1, 1)
        self.uiHdaDiskImageLabel = QtGui.QLabel(self.uiDiskWizardPage)
        self.uiHdaDiskImageLabel.setObjectName(_fromUtf8("uiHdaDiskImageLabel"))
        self.gridLayout_6.addWidget(self.uiHdaDiskImageLabel, 0, 0, 1, 1)
        QemuVMWizard.addPage(self.uiDiskWizardPage)
        self.uiASAWizardPage = QtGui.QWizardPage()
        self.uiASAWizardPage.setObjectName(_fromUtf8("uiASAWizardPage"))
        self.gridLayout_5 = QtGui.QGridLayout(self.uiASAWizardPage)
        self.gridLayout_5.setObjectName(_fromUtf8("gridLayout_5"))
        self.uiLinuxBootGroupBox = QtGui.QGroupBox(self.uiASAWizardPage)
        self.uiLinuxBootGroupBox.setObjectName(_fromUtf8("uiLinuxBootGroupBox"))
        self.gridLayout_3 = QtGui.QGridLayout(self.uiLinuxBootGroupBox)
        self.gridLayout_3.setObjectName(_fromUtf8("gridLayout_3"))
        self.uiKernelImageLineEdit = QtGui.QLineEdit(self.uiLinuxBootGroupBox)
        self.uiKernelImageLineEdit.setObjectName(_fromUtf8("uiKernelImageLineEdit"))
        self.gridLayout_3.addWidget(self.uiKernelImageLineEdit, 1, 1, 1, 1)
        self.uiInitrdLabel = QtGui.QLabel(self.uiLinuxBootGroupBox)
        self.uiInitrdLabel.setObjectName(_fromUtf8("uiInitrdLabel"))
        self.gridLayout_3.addWidget(self.uiInitrdLabel, 0, 0, 1, 1)
        self.uiKernelImageLabel = QtGui.QLabel(self.uiLinuxBootGroupBox)
        self.uiKernelImageLabel.setObjectName(_fromUtf8("uiKernelImageLabel"))
        self.gridLayout_3.addWidget(self.uiKernelImageLabel, 1, 0, 1, 1)
        self.uiInitrdLineEdit = QtGui.QLineEdit(self.uiLinuxBootGroupBox)
        self.uiInitrdLineEdit.setObjectName(_fromUtf8("uiInitrdLineEdit"))
        self.gridLayout_3.addWidget(self.uiInitrdLineEdit, 0, 1, 1, 1)
        self.uiInitrdToolButton = QtGui.QToolButton(self.uiLinuxBootGroupBox)
        self.uiInitrdToolButton.setToolButtonStyle(QtCore.Qt.ToolButtonTextOnly)
        self.uiInitrdToolButton.setObjectName(_fromUtf8("uiInitrdToolButton"))
        self.gridLayout_3.addWidget(self.uiInitrdToolButton, 0, 2, 1, 1)
        self.uiKernelImageToolButton = QtGui.QToolButton(self.uiLinuxBootGroupBox)
        self.uiKernelImageToolButton.setToolButtonStyle(QtCore.Qt.ToolButtonTextOnly)
        self.uiKernelImageToolButton.setObjectName(_fromUtf8("uiKernelImageToolButton"))
        self.gridLayout_3.addWidget(self.uiKernelImageToolButton, 1, 2, 1, 1)
        self.gridLayout_5.addWidget(self.uiLinuxBootGroupBox, 0, 0, 1, 1)
        QemuVMWizard.addPage(self.uiASAWizardPage)
        self.uiDiskImageHdbWizardPage = QtGui.QWizardPage()
        self.uiDiskImageHdbWizardPage.setObjectName(_fromUtf8("uiDiskImageHdbWizardPage"))
        self.gridLayout_7 = QtGui.QGridLayout(self.uiDiskImageHdbWizardPage)
        self.gridLayout_7.setObjectName(_fromUtf8("gridLayout_7"))
        self.uiHdbDiskImageLabel = QtGui.QLabel(self.uiDiskImageHdbWizardPage)
        self.uiHdbDiskImageLabel.setObjectName(_fromUtf8("uiHdbDiskImageLabel"))
        self.gridLayout_7.addWidget(self.uiHdbDiskImageLabel, 0, 0, 1, 1)
        self.horizontalLayout_5 = QtGui.QHBoxLayout()
        self.horizontalLayout_5.setObjectName(_fromUtf8("horizontalLayout_5"))
        self.uiHdbDiskImageLineEdit = QtGui.QLineEdit(self.uiDiskImageHdbWizardPage)
        self.uiHdbDiskImageLineEdit.setObjectName(_fromUtf8("uiHdbDiskImageLineEdit"))
        self.horizontalLayout_5.addWidget(self.uiHdbDiskImageLineEdit)
        self.uiHdbDiskImageToolButton = QtGui.QToolButton(self.uiDiskImageHdbWizardPage)
        self.uiHdbDiskImageToolButton.setToolButtonStyle(QtCore.Qt.ToolButtonTextOnly)
        self.uiHdbDiskImageToolButton.setObjectName(_fromUtf8("uiHdbDiskImageToolButton"))
        self.horizontalLayout_5.addWidget(self.uiHdbDiskImageToolButton)
        self.gridLayout_7.addLayout(self.horizontalLayout_5, 0, 1, 1, 1)
        QemuVMWizard.addPage(self.uiDiskImageHdbWizardPage)

        self.retranslateUi(QemuVMWizard)
        QtCore.QMetaObject.connectSlotsByName(QemuVMWizard)
        QemuVMWizard.setTabOrder(self.uiNameLineEdit, self.uiQemuListComboBox)
        QemuVMWizard.setTabOrder(self.uiQemuListComboBox, self.uiRamSpinBox)
        QemuVMWizard.setTabOrder(self.uiRamSpinBox, self.uiHdaDiskImageLineEdit)
        QemuVMWizard.setTabOrder(self.uiHdaDiskImageLineEdit, self.uiHdaDiskImageToolButton)
        QemuVMWizard.setTabOrder(self.uiHdaDiskImageToolButton, self.uiInitrdLineEdit)
        QemuVMWizard.setTabOrder(self.uiInitrdLineEdit, self.uiInitrdToolButton)
        QemuVMWizard.setTabOrder(self.uiInitrdToolButton, self.uiKernelImageLineEdit)
        QemuVMWizard.setTabOrder(self.uiKernelImageLineEdit, self.uiKernelImageToolButton)

    def retranslateUi(self, QemuVMWizard):
        QemuVMWizard.setWindowTitle(_translate("QemuVMWizard", "New QEMU VM template", None))
        self.uiServerWizardPage.setTitle(_translate("QemuVMWizard", "Server", None))
        self.uiServerWizardPage.setSubTitle(_translate("QemuVMWizard", "Please choose a server type to run your new QEMU VM.", None))
        self.uiServerTypeGroupBox.setTitle(_translate("QemuVMWizard", "Server type", None))
        self.uiRemoteRadioButton.setText(_translate("QemuVMWizard", "Remote", None))
        self.uiCloudRadioButton.setText(_translate("QemuVMWizard", "Cloud", None))
        self.uiLocalRadioButton.setText(_translate("QemuVMWizard", "Local", None))
        self.uiRemoteServersGroupBox.setTitle(_translate("QemuVMWizard", "Remote servers", None))
        self.uiRemoteServersLabel.setText(_translate("QemuVMWizard", "Run on server:", None))
        self.uiTypeWizardPage.setTitle(_translate("QemuVMWizard", "QEMU VM type", None))
        self.uiTypeWizardPage.setSubTitle(_translate("QemuVMWizard", "Please choose a type of QEMU VM to help with pre-configuration.", None))
        self.uiTypeLabel.setText(_translate("QemuVMWizard", "Type:", None))
        self.uiNameWizardPage.setTitle(_translate("QemuVMWizard", "QEMU VM name", None))
        self.uiNameWizardPage.setSubTitle(_translate("QemuVMWizard", "Please choose a descriptive name for your new QEMU virtual machine.", None))
        self.uiNameLabel.setText(_translate("QemuVMWizard", "Name:", None))
        self.uiBinaryMemoryWizardPage.setTitle(_translate("QemuVMWizard", "QEMU binary and memory", None))
        self.uiBinaryMemoryWizardPage.setSubTitle(_translate("QemuVMWizard", "Please check the Qemu binary is correctly set and the virtual machine has enough memory to work.", None))
        self.uiRamLabel.setText(_translate("QemuVMWizard", "RAM:", None))
        self.uiQemuListLabel.setText(_translate("QemuVMWizard", "Qemu binary:", None))
        self.uiRamSpinBox.setSuffix(_translate("QemuVMWizard", " MB", None))
        self.uiDiskWizardPage.setTitle(_translate("QemuVMWizard", "Disk image", None))
        self.uiDiskWizardPage.setSubTitle(_translate("QemuVMWizard", "Please choose a base disk image for your virtual machine.", None))
        self.uiHdaDiskImageToolButton.setText(_translate("QemuVMWizard", "&Browse...", None))
        self.uiHdaDiskImageLabel.setText(_translate("QemuVMWizard", "Disk image (hda):", None))
        self.uiASAWizardPage.setTitle(_translate("QemuVMWizard", "ASA VM", None))
        self.uiASAWizardPage.setSubTitle(_translate("QemuVMWizard", "Please choose a initrd and a kernel image.", None))
        self.uiLinuxBootGroupBox.setTitle(_translate("QemuVMWizard", "Linux boot specific settings", None))
        self.uiInitrdLabel.setText(_translate("QemuVMWizard", "Initial RAM disk (initrd):", None))
        self.uiKernelImageLabel.setText(_translate("QemuVMWizard", "Kernel image (vmlinuz):", None))
        self.uiInitrdToolButton.setText(_translate("QemuVMWizard", "&Browse...", None))
        self.uiKernelImageToolButton.setText(_translate("QemuVMWizard", "&Browse...", None))
        self.uiDiskImageHdbWizardPage.setTitle(_translate("QemuVMWizard", "Additional disk image", None))
        self.uiDiskImageHdbWizardPage.setSubTitle(_translate("QemuVMWizard", "Please add an additional disk image for IDS.", None))
        self.uiHdbDiskImageLabel.setText(_translate("QemuVMWizard", "Disk image (hdb):", None))
        self.uiHdbDiskImageToolButton.setText(_translate("QemuVMWizard", "&Browse...", None))

