# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/grossmj/PycharmProjects/gns3-gui/gns3/ui/main_window.ui'
#
# Created: Mon Mar  9 17:21:40 2015
#      by: PyQt4 UI code generator 4.10.4
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName(_fromUtf8("MainWindow"))
        MainWindow.setWindowModality(QtCore.Qt.NonModal)
        MainWindow.resize(984, 715)
        MainWindow.setContextMenuPolicy(QtCore.Qt.PreventContextMenu)
        MainWindow.setStyleSheet(_fromUtf8("#toolBar_Devices QToolButton {\n"
"width: 50px;\n"
"height: 55px;\n"
"border:solid 1px black opacity 0.4;\n"
"background-none;\n"
"}\n"
"\n"
"#toolBar_General QToolButton {\n"
"width: 36px;\n"
"height: 36px;\n"
"border:solid 1px black opacity 0.4;\n"
"background-none;\n"
"}\n"
"\n"
""))
        MainWindow.setDockOptions(QtGui.QMainWindow.AllowTabbedDocks|QtGui.QMainWindow.AnimatedDocks)
        MainWindow.setUnifiedTitleAndToolBarOnMac(False)
        self.uiCentralWidget = QtGui.QWidget(MainWindow)
        self.uiCentralWidget.setObjectName(_fromUtf8("uiCentralWidget"))
        self.gridlayout = QtGui.QGridLayout(self.uiCentralWidget)
        self.gridlayout.setMargin(0)
        self.gridlayout.setSpacing(0)
        self.gridlayout.setObjectName(_fromUtf8("gridlayout"))
        self.uiGraphicsView = GraphicsView(self.uiCentralWidget)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiGraphicsView.sizePolicy().hasHeightForWidth())
        self.uiGraphicsView.setSizePolicy(sizePolicy)
        self.uiGraphicsView.setObjectName(_fromUtf8("uiGraphicsView"))
        self.gridlayout.addWidget(self.uiGraphicsView, 0, 0, 1, 1)
        MainWindow.setCentralWidget(self.uiCentralWidget)
        self.uiMenuBar = QtGui.QMenuBar(MainWindow)
        self.uiMenuBar.setGeometry(QtCore.QRect(0, 0, 984, 25))
        self.uiMenuBar.setObjectName(_fromUtf8("uiMenuBar"))
        self.uiEditMenu = QtGui.QMenu(self.uiMenuBar)
        self.uiEditMenu.setObjectName(_fromUtf8("uiEditMenu"))
        self.uiFileMenu = QtGui.QMenu(self.uiMenuBar)
        self.uiFileMenu.setObjectName(_fromUtf8("uiFileMenu"))
        self.uiHelpMenu = QtGui.QMenu(self.uiMenuBar)
        self.uiHelpMenu.setObjectName(_fromUtf8("uiHelpMenu"))
        self.uiViewMenu = QtGui.QMenu(self.uiMenuBar)
        self.uiViewMenu.setObjectName(_fromUtf8("uiViewMenu"))
        self.uiDocksMenu = QtGui.QMenu(self.uiViewMenu)
        self.uiDocksMenu.setObjectName(_fromUtf8("uiDocksMenu"))
        self.uiControlMenu = QtGui.QMenu(self.uiMenuBar)
        self.uiControlMenu.setObjectName(_fromUtf8("uiControlMenu"))
        self.uiAnnotateMenu = QtGui.QMenu(self.uiMenuBar)
        self.uiAnnotateMenu.setObjectName(_fromUtf8("uiAnnotateMenu"))
        self.uiDeviceMenu = QtGui.QMenu(self.uiMenuBar)
        self.uiDeviceMenu.setObjectName(_fromUtf8("uiDeviceMenu"))
        self.uiToolsMenu = QtGui.QMenu(self.uiMenuBar)
        self.uiToolsMenu.setObjectName(_fromUtf8("uiToolsMenu"))
        MainWindow.setMenuBar(self.uiMenuBar)
        self.uiStatusBar = QtGui.QStatusBar(MainWindow)
        self.uiStatusBar.setObjectName(_fromUtf8("uiStatusBar"))
        MainWindow.setStatusBar(self.uiStatusBar)
        self.uiGeneralToolBar = QtGui.QToolBar(MainWindow)
        self.uiGeneralToolBar.setToolTip(_fromUtf8(""))
        self.uiGeneralToolBar.setStatusTip(_fromUtf8(""))
        self.uiGeneralToolBar.setOrientation(QtCore.Qt.Horizontal)
        self.uiGeneralToolBar.setIconSize(QtCore.QSize(32, 32))
        self.uiGeneralToolBar.setObjectName(_fromUtf8("uiGeneralToolBar"))
        MainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.uiGeneralToolBar)
        self.uiNodesDockWidget = QtGui.QDockWidget(MainWindow)
        self.uiNodesDockWidget.setEnabled(True)
        self.uiNodesDockWidget.setVisible(True)
        self.uiNodesDockWidget.setFloating(False)
        self.uiNodesDockWidget.setAllowedAreas(QtCore.Qt.LeftDockWidgetArea|QtCore.Qt.RightDockWidgetArea)
        self.uiNodesDockWidget.setObjectName(_fromUtf8("uiNodesDockWidget"))
        self.uiNodesDockWidgetContents = QtGui.QWidget()
        self.uiNodesDockWidgetContents.setObjectName(_fromUtf8("uiNodesDockWidgetContents"))
        self.vboxlayout = QtGui.QVBoxLayout(self.uiNodesDockWidgetContents)
        self.vboxlayout.setSpacing(0)
        self.vboxlayout.setMargin(0)
        self.vboxlayout.setObjectName(_fromUtf8("vboxlayout"))
        self.uiNodesView = NodesView(self.uiNodesDockWidgetContents)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiNodesView.sizePolicy().hasHeightForWidth())
        self.uiNodesView.setSizePolicy(sizePolicy)
        self.uiNodesView.setDragEnabled(False)
        self.uiNodesView.setIconSize(QtCore.QSize(32, 32))
        self.uiNodesView.setRootIsDecorated(False)
        self.uiNodesView.setObjectName(_fromUtf8("uiNodesView"))
        self.uiNodesView.header().setVisible(False)
        self.vboxlayout.addWidget(self.uiNodesView)
        self.uiNodesDockWidget.setWidget(self.uiNodesDockWidgetContents)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(1), self.uiNodesDockWidget)
        self.uiBrowsersToolBar = QtGui.QToolBar(MainWindow)
        self.uiBrowsersToolBar.setIconSize(QtCore.QSize(48, 48))
        self.uiBrowsersToolBar.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.uiBrowsersToolBar.setObjectName(_fromUtf8("uiBrowsersToolBar"))
        MainWindow.addToolBar(QtCore.Qt.LeftToolBarArea, self.uiBrowsersToolBar)
        self.uiControlToolBar = QtGui.QToolBar(MainWindow)
        self.uiControlToolBar.setIconSize(QtCore.QSize(32, 32))
        self.uiControlToolBar.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.uiControlToolBar.setObjectName(_fromUtf8("uiControlToolBar"))
        MainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.uiControlToolBar)
        self.uiConsoleDockWidget = QtGui.QDockWidget(MainWindow)
        self.uiConsoleDockWidget.setMaximumSize(QtCore.QSize(524287, 524287))
        self.uiConsoleDockWidget.setAllowedAreas(QtCore.Qt.AllDockWidgetAreas)
        self.uiConsoleDockWidget.setObjectName(_fromUtf8("uiConsoleDockWidget"))
        self.uiConsoleDockWidgetContents = QtGui.QWidget()
        self.uiConsoleDockWidgetContents.setObjectName(_fromUtf8("uiConsoleDockWidgetContents"))
        self.vboxlayout1 = QtGui.QVBoxLayout(self.uiConsoleDockWidgetContents)
        self.vboxlayout1.setSpacing(0)
        self.vboxlayout1.setMargin(0)
        self.vboxlayout1.setObjectName(_fromUtf8("vboxlayout1"))
        self.uiConsoleTextEdit = ConsoleView(self.uiConsoleDockWidgetContents)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiConsoleTextEdit.sizePolicy().hasHeightForWidth())
        self.uiConsoleTextEdit.setSizePolicy(sizePolicy)
        self.uiConsoleTextEdit.setObjectName(_fromUtf8("uiConsoleTextEdit"))
        self.vboxlayout1.addWidget(self.uiConsoleTextEdit)
        self.uiConsoleDockWidget.setWidget(self.uiConsoleDockWidgetContents)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(8), self.uiConsoleDockWidget)
        self.uiAnnotationToolBar = QtGui.QToolBar(MainWindow)
        self.uiAnnotationToolBar.setIconSize(QtCore.QSize(32, 32))
        self.uiAnnotationToolBar.setObjectName(_fromUtf8("uiAnnotationToolBar"))
        MainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.uiAnnotationToolBar)
        self.uiTopologySummaryDockWidget = QtGui.QDockWidget(MainWindow)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiTopologySummaryDockWidget.sizePolicy().hasHeightForWidth())
        self.uiTopologySummaryDockWidget.setSizePolicy(sizePolicy)
        self.uiTopologySummaryDockWidget.setAllowedAreas(QtCore.Qt.LeftDockWidgetArea|QtCore.Qt.RightDockWidgetArea)
        self.uiTopologySummaryDockWidget.setObjectName(_fromUtf8("uiTopologySummaryDockWidget"))
        self.uiTopologySummaryDockWidgetContents = QtGui.QWidget()
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiTopologySummaryDockWidgetContents.sizePolicy().hasHeightForWidth())
        self.uiTopologySummaryDockWidgetContents.setSizePolicy(sizePolicy)
        self.uiTopologySummaryDockWidgetContents.setObjectName(_fromUtf8("uiTopologySummaryDockWidgetContents"))
        self.gridlayout1 = QtGui.QGridLayout(self.uiTopologySummaryDockWidgetContents)
        self.gridlayout1.setMargin(0)
        self.gridlayout1.setSpacing(0)
        self.gridlayout1.setObjectName(_fromUtf8("gridlayout1"))
        self.uiTopologySummaryTreeWidget = TopologySummaryView(self.uiTopologySummaryDockWidgetContents)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiTopologySummaryTreeWidget.sizePolicy().hasHeightForWidth())
        self.uiTopologySummaryTreeWidget.setSizePolicy(sizePolicy)
        self.uiTopologySummaryTreeWidget.setObjectName(_fromUtf8("uiTopologySummaryTreeWidget"))
        self.uiTopologySummaryTreeWidget.header().setVisible(False)
        self.gridlayout1.addWidget(self.uiTopologySummaryTreeWidget, 0, 0, 1, 1)
        self.uiTopologySummaryDockWidget.setWidget(self.uiTopologySummaryDockWidgetContents)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(2), self.uiTopologySummaryDockWidget)
        self.uiCloudInspectorDockWidget = QtGui.QDockWidget(MainWindow)
        self.uiCloudInspectorDockWidget.setEnabled(True)
        self.uiCloudInspectorDockWidget.setObjectName(_fromUtf8("uiCloudInspectorDockWidget"))
        self.uiCloudInspectorDockWidgetContents = QtGui.QWidget()
        self.uiCloudInspectorDockWidgetContents.setObjectName(_fromUtf8("uiCloudInspectorDockWidgetContents"))
        self.verticalLayout = QtGui.QVBoxLayout(self.uiCloudInspectorDockWidgetContents)
        self.verticalLayout.setMargin(0)
        self.verticalLayout.setObjectName(_fromUtf8("verticalLayout"))
        self.CloudInspectorView = CloudInspectorView(self.uiCloudInspectorDockWidgetContents)
        self.CloudInspectorView.setAutoFillBackground(False)
        self.CloudInspectorView.setObjectName(_fromUtf8("CloudInspectorView"))
        self.verticalLayout.addWidget(self.CloudInspectorView)
        self.uiCloudInspectorDockWidget.setWidget(self.uiCloudInspectorDockWidgetContents)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(2), self.uiCloudInspectorDockWidget)
        self.uiAboutAction = QtGui.QAction(MainWindow)
        self.uiAboutAction.setMenuRole(QtGui.QAction.AboutRole)
        self.uiAboutAction.setObjectName(_fromUtf8("uiAboutAction"))
        self.uiQuitAction = QtGui.QAction(MainWindow)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/quit.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiQuitAction.setIcon(icon)
        self.uiQuitAction.setObjectName(_fromUtf8("uiQuitAction"))
        self.uiOpenProjectAction = QtGui.QAction(MainWindow)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/open.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiOpenProjectAction.setIcon(icon1)
        self.uiOpenProjectAction.setObjectName(_fromUtf8("uiOpenProjectAction"))
        self.uiSaveProjectAction = QtGui.QAction(MainWindow)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/save.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiSaveProjectAction.setIcon(icon2)
        self.uiSaveProjectAction.setObjectName(_fromUtf8("uiSaveProjectAction"))
        self.uiOnlineHelpAction = QtGui.QAction(MainWindow)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/help.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiOnlineHelpAction.setIcon(icon3)
        self.uiOnlineHelpAction.setObjectName(_fromUtf8("uiOnlineHelpAction"))
        self.uiScreenshotAction = QtGui.QAction(MainWindow)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/camera-photo.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon4.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/camera-photo-hover.svg")), QtGui.QIcon.Active, QtGui.QIcon.Off)
        self.uiScreenshotAction.setIcon(icon4)
        self.uiScreenshotAction.setObjectName(_fromUtf8("uiScreenshotAction"))
        self.uiStartAllAction = QtGui.QAction(MainWindow)
        self.uiStartAllAction.setEnabled(True)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/start.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon5.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/start-hover.svg")), QtGui.QIcon.Active, QtGui.QIcon.Off)
        self.uiStartAllAction.setIcon(icon5)
        self.uiStartAllAction.setObjectName(_fromUtf8("uiStartAllAction"))
        self.uiStopAllAction = QtGui.QAction(MainWindow)
        self.uiStopAllAction.setEnabled(True)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/stop.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon6.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/stop-hover.svg")), QtGui.QIcon.Active, QtGui.QIcon.Off)
        self.uiStopAllAction.setIcon(icon6)
        self.uiStopAllAction.setObjectName(_fromUtf8("uiStopAllAction"))
        self.uiShowNamesAction = QtGui.QAction(MainWindow)
        self.uiShowNamesAction.setCheckable(True)
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/show-hostname.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiShowNamesAction.setIcon(icon7)
        self.uiShowNamesAction.setObjectName(_fromUtf8("uiShowNamesAction"))
        self.uiConsoleAllAction = QtGui.QAction(MainWindow)
        self.uiConsoleAllAction.setEnabled(True)
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/console.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiConsoleAllAction.setIcon(icon8)
        self.uiConsoleAllAction.setObjectName(_fromUtf8("uiConsoleAllAction"))
        self.uiAboutQtAction = QtGui.QAction(MainWindow)
        self.uiAboutQtAction.setMenuRole(QtGui.QAction.AboutQtRole)
        self.uiAboutQtAction.setObjectName(_fromUtf8("uiAboutQtAction"))
        self.uiZoomInAction = QtGui.QAction(MainWindow)
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/zoom-in.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon9.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/zoom-in-hover.png")), QtGui.QIcon.Active, QtGui.QIcon.Off)
        self.uiZoomInAction.setIcon(icon9)
        self.uiZoomInAction.setObjectName(_fromUtf8("uiZoomInAction"))
        self.uiZoomOutAction = QtGui.QAction(MainWindow)
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/zoom-out.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon10.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/zoom-out-hover.png")), QtGui.QIcon.Active, QtGui.QIcon.Off)
        self.uiZoomOutAction.setIcon(icon10)
        self.uiZoomOutAction.setObjectName(_fromUtf8("uiZoomOutAction"))
        self.uiZoomResetAction = QtGui.QAction(MainWindow)
        self.uiZoomResetAction.setObjectName(_fromUtf8("uiZoomResetAction"))
        self.uiSelectAllAction = QtGui.QAction(MainWindow)
        self.uiSelectAllAction.setObjectName(_fromUtf8("uiSelectAllAction"))
        self.uiSelectNoneAction = QtGui.QAction(MainWindow)
        self.uiSelectNoneAction.setObjectName(_fromUtf8("uiSelectNoneAction"))
        self.uiPreferencesAction = QtGui.QAction(MainWindow)
        icon11 = QtGui.QIcon()
        icon11.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/applications.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiPreferencesAction.setIcon(icon11)
        self.uiPreferencesAction.setObjectName(_fromUtf8("uiPreferencesAction"))
        self.uiSuspendAllAction = QtGui.QAction(MainWindow)
        icon12 = QtGui.QIcon()
        icon12.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/pause.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon12.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/pause-hover.svg")), QtGui.QIcon.Active, QtGui.QIcon.Off)
        self.uiSuspendAllAction.setIcon(icon12)
        self.uiSuspendAllAction.setObjectName(_fromUtf8("uiSuspendAllAction"))
        self.uiAddNoteAction = QtGui.QAction(MainWindow)
        self.uiAddNoteAction.setCheckable(True)
        icon13 = QtGui.QIcon()
        icon13.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/add-note.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiAddNoteAction.setIcon(icon13)
        self.uiAddNoteAction.setObjectName(_fromUtf8("uiAddNoteAction"))
        self.uiNewProjectAction = QtGui.QAction(MainWindow)
        icon14 = QtGui.QIcon()
        icon14.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/new-project.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiNewProjectAction.setIcon(icon14)
        self.uiNewProjectAction.setObjectName(_fromUtf8("uiNewProjectAction"))
        self.uiImportExportConfigsAction = QtGui.QAction(MainWindow)
        icon15 = QtGui.QIcon()
        icon15.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/import_export_configs.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiImportExportConfigsAction.setIcon(icon15)
        self.uiImportExportConfigsAction.setObjectName(_fromUtf8("uiImportExportConfigsAction"))
        self.uiInsertImageAction = QtGui.QAction(MainWindow)
        self.uiInsertImageAction.setCheckable(False)
        icon16 = QtGui.QIcon()
        icon16.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/image.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiInsertImageAction.setIcon(icon16)
        self.uiInsertImageAction.setObjectName(_fromUtf8("uiInsertImageAction"))
        self.uiDrawRectangleAction = QtGui.QAction(MainWindow)
        self.uiDrawRectangleAction.setCheckable(True)
        icon17 = QtGui.QIcon()
        icon17.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/rectangle.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon17.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/rectangle-hover.svg")), QtGui.QIcon.Active, QtGui.QIcon.Off)
        self.uiDrawRectangleAction.setIcon(icon17)
        self.uiDrawRectangleAction.setObjectName(_fromUtf8("uiDrawRectangleAction"))
        self.uiDrawEllipseAction = QtGui.QAction(MainWindow)
        self.uiDrawEllipseAction.setCheckable(True)
        icon18 = QtGui.QIcon()
        icon18.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/ellipse.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon18.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/ellipse-hover.svg")), QtGui.QIcon.Active, QtGui.QIcon.Off)
        self.uiDrawEllipseAction.setIcon(icon18)
        self.uiDrawEllipseAction.setObjectName(_fromUtf8("uiDrawEllipseAction"))
        self.uiShowPortNamesAction = QtGui.QAction(MainWindow)
        self.uiShowPortNamesAction.setCheckable(True)
        icon19 = QtGui.QIcon()
        icon19.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/show-interface-names.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiShowPortNamesAction.setIcon(icon19)
        self.uiShowPortNamesAction.setObjectName(_fromUtf8("uiShowPortNamesAction"))
        self.uiSnapshotAction = QtGui.QAction(MainWindow)
        icon20 = QtGui.QIcon()
        icon20.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/snapshot.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiSnapshotAction.setIcon(icon20)
        self.uiSnapshotAction.setObjectName(_fromUtf8("uiSnapshotAction"))
        self.uiShowLayersAction = QtGui.QAction(MainWindow)
        self.uiShowLayersAction.setCheckable(True)
        self.uiShowLayersAction.setObjectName(_fromUtf8("uiShowLayersAction"))
        self.uiSaveProjectAsAction = QtGui.QAction(MainWindow)
        icon21 = QtGui.QIcon()
        icon21.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/save-as-project.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiSaveProjectAsAction.setIcon(icon21)
        self.uiSaveProjectAsAction.setObjectName(_fromUtf8("uiSaveProjectAsAction"))
        self.uiReloadAllAction = QtGui.QAction(MainWindow)
        icon22 = QtGui.QIcon()
        icon22.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/reload.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiReloadAllAction.setIcon(icon22)
        self.uiReloadAllAction.setObjectName(_fromUtf8("uiReloadAllAction"))
        self.uiAuxConsoleAllAction = QtGui.QAction(MainWindow)
        self.uiAuxConsoleAllAction.setEnabled(True)
        icon23 = QtGui.QIcon()
        icon23.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/aux-console.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiAuxConsoleAllAction.setIcon(icon23)
        self.uiAuxConsoleAllAction.setObjectName(_fromUtf8("uiAuxConsoleAllAction"))
        self.uiResetPortLabelsAction = QtGui.QAction(MainWindow)
        self.uiResetPortLabelsAction.setObjectName(_fromUtf8("uiResetPortLabelsAction"))
        self.uiCheckForUpdateAction = QtGui.QAction(MainWindow)
        self.uiCheckForUpdateAction.setObjectName(_fromUtf8("uiCheckForUpdateAction"))
        self.uiEnergySavingStyleAction = QtGui.QAction(MainWindow)
        self.uiEnergySavingStyleAction.setCheckable(True)
        self.uiEnergySavingStyleAction.setObjectName(_fromUtf8("uiEnergySavingStyleAction"))
        self.uiDefaultStyleAction = QtGui.QAction(MainWindow)
        self.uiDefaultStyleAction.setCheckable(True)
        self.uiDefaultStyleAction.setChecked(True)
        self.uiDefaultStyleAction.setObjectName(_fromUtf8("uiDefaultStyleAction"))
        self.uiBrowseRoutersAction = QtGui.QAction(MainWindow)
        icon24 = QtGui.QIcon()
        icon24.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/router.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon24.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/router-hover.png")), QtGui.QIcon.Active, QtGui.QIcon.Off)
        self.uiBrowseRoutersAction.setIcon(icon24)
        self.uiBrowseRoutersAction.setObjectName(_fromUtf8("uiBrowseRoutersAction"))
        self.uiBrowseSwitchesAction = QtGui.QAction(MainWindow)
        icon25 = QtGui.QIcon()
        icon25.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/switch.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon25.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/switch-hover.png")), QtGui.QIcon.Active, QtGui.QIcon.Off)
        self.uiBrowseSwitchesAction.setIcon(icon25)
        self.uiBrowseSwitchesAction.setObjectName(_fromUtf8("uiBrowseSwitchesAction"))
        self.uiBrowseEndDevicesAction = QtGui.QAction(MainWindow)
        icon26 = QtGui.QIcon()
        icon26.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/PC.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon26.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/PC-hover.png")), QtGui.QIcon.Active, QtGui.QIcon.Off)
        self.uiBrowseEndDevicesAction.setIcon(icon26)
        self.uiBrowseEndDevicesAction.setObjectName(_fromUtf8("uiBrowseEndDevicesAction"))
        self.uiBrowseSecurityDevicesAction = QtGui.QAction(MainWindow)
        icon27 = QtGui.QIcon()
        icon27.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/firewall.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon27.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/firewall-hover.png")), QtGui.QIcon.Active, QtGui.QIcon.Off)
        self.uiBrowseSecurityDevicesAction.setIcon(icon27)
        self.uiBrowseSecurityDevicesAction.setObjectName(_fromUtf8("uiBrowseSecurityDevicesAction"))
        self.uiBrowseAllDevicesAction = QtGui.QAction(MainWindow)
        icon28 = QtGui.QIcon()
        icon28.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/browse-all-icons.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon28.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/browse-all-icons-hover.png")), QtGui.QIcon.Active, QtGui.QIcon.Off)
        self.uiBrowseAllDevicesAction.setIcon(icon28)
        self.uiBrowseAllDevicesAction.setObjectName(_fromUtf8("uiBrowseAllDevicesAction"))
        self.uiAddLinkAction = QtGui.QAction(MainWindow)
        self.uiAddLinkAction.setCheckable(True)
        icon29 = QtGui.QIcon()
        icon29.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/connection-new.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon29.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/cancel-connection.svg")), QtGui.QIcon.Normal, QtGui.QIcon.On)
        icon29.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/connection-new-hover.svg")), QtGui.QIcon.Active, QtGui.QIcon.Off)
        icon29.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/cancel-connection.svg")), QtGui.QIcon.Active, QtGui.QIcon.On)
        self.uiAddLinkAction.setIcon(icon29)
        self.uiAddLinkAction.setObjectName(_fromUtf8("uiAddLinkAction"))
        self.uiGettingStartedAction = QtGui.QAction(MainWindow)
        self.uiGettingStartedAction.setObjectName(_fromUtf8("uiGettingStartedAction"))
        self.uiLabInstructionsAction = QtGui.QAction(MainWindow)
        self.uiLabInstructionsAction.setObjectName(_fromUtf8("uiLabInstructionsAction"))
        self.uiFitInViewAction = QtGui.QAction(MainWindow)
        self.uiFitInViewAction.setObjectName(_fromUtf8("uiFitInViewAction"))
        self.uiExportProjectAction = QtGui.QAction(MainWindow)
        self.uiExportProjectAction.setVisible(False)
        self.uiExportProjectAction.setObjectName(_fromUtf8("uiExportProjectAction"))
        self.uiImportProjectAction = QtGui.QAction(MainWindow)
        self.uiImportProjectAction.setVisible(False)
        self.uiImportProjectAction.setObjectName(_fromUtf8("uiImportProjectAction"))
        self.uiMoveLocalProjectToCloudAction = QtGui.QAction(MainWindow)
        self.uiMoveLocalProjectToCloudAction.setVisible(False)
        self.uiMoveLocalProjectToCloudAction.setObjectName(_fromUtf8("uiMoveLocalProjectToCloudAction"))
        self.uiMoveCloudProjectToLocalAction = QtGui.QAction(MainWindow)
        self.uiMoveCloudProjectToLocalAction.setVisible(False)
        self.uiMoveCloudProjectToLocalAction.setObjectName(_fromUtf8("uiMoveCloudProjectToLocalAction"))
        self.uiDarkStyleAction = QtGui.QAction(MainWindow)
        self.uiDarkStyleAction.setObjectName(_fromUtf8("uiDarkStyleAction"))
        self.uiActionFullscreen = QtGui.QAction(MainWindow)
        self.uiActionFullscreen.setObjectName(_fromUtf8("uiActionFullscreen"))
        self.uiVPCSAction = QtGui.QAction(MainWindow)
        self.uiVPCSAction.setObjectName(_fromUtf8("uiVPCSAction"))
        self.uiEditMenu.addAction(self.uiSelectAllAction)
        self.uiEditMenu.addAction(self.uiSelectNoneAction)
        self.uiEditMenu.addSeparator()
        self.uiEditMenu.addAction(self.uiPreferencesAction)
        self.uiFileMenu.addAction(self.uiNewProjectAction)
        self.uiFileMenu.addAction(self.uiOpenProjectAction)
        self.uiFileMenu.addAction(self.uiSaveProjectAction)
        self.uiFileMenu.addAction(self.uiSaveProjectAsAction)
        self.uiFileMenu.addAction(self.uiExportProjectAction)
        self.uiFileMenu.addAction(self.uiImportProjectAction)
        self.uiFileMenu.addSeparator()
        self.uiFileMenu.addAction(self.uiMoveLocalProjectToCloudAction)
        self.uiFileMenu.addAction(self.uiMoveCloudProjectToLocalAction)
        self.uiFileMenu.addSeparator()
        self.uiFileMenu.addAction(self.uiImportExportConfigsAction)
        self.uiFileMenu.addAction(self.uiScreenshotAction)
        self.uiFileMenu.addAction(self.uiSnapshotAction)
        self.uiFileMenu.addSeparator()
        self.uiFileMenu.addAction(self.uiQuitAction)
        self.uiHelpMenu.addAction(self.uiOnlineHelpAction)
        self.uiHelpMenu.addAction(self.uiCheckForUpdateAction)
        self.uiHelpMenu.addAction(self.uiGettingStartedAction)
        self.uiHelpMenu.addAction(self.uiLabInstructionsAction)
        self.uiHelpMenu.addAction(self.uiAboutQtAction)
        self.uiHelpMenu.addAction(self.uiAboutAction)
        self.uiViewMenu.addAction(self.uiActionFullscreen)
        self.uiViewMenu.addSeparator()
        self.uiViewMenu.addAction(self.uiZoomInAction)
        self.uiViewMenu.addAction(self.uiZoomOutAction)
        self.uiViewMenu.addAction(self.uiZoomResetAction)
        self.uiViewMenu.addAction(self.uiFitInViewAction)
        self.uiViewMenu.addSeparator()
        self.uiViewMenu.addAction(self.uiShowLayersAction)
        self.uiViewMenu.addAction(self.uiResetPortLabelsAction)
        self.uiViewMenu.addAction(self.uiShowPortNamesAction)
        self.uiViewMenu.addSeparator()
        self.uiViewMenu.addAction(self.uiDocksMenu.menuAction())
        self.uiControlMenu.addAction(self.uiStartAllAction)
        self.uiControlMenu.addAction(self.uiSuspendAllAction)
        self.uiControlMenu.addAction(self.uiStopAllAction)
        self.uiControlMenu.addAction(self.uiReloadAllAction)
        self.uiControlMenu.addAction(self.uiAuxConsoleAllAction)
        self.uiControlMenu.addAction(self.uiConsoleAllAction)
        self.uiAnnotateMenu.addAction(self.uiAddNoteAction)
        self.uiAnnotateMenu.addAction(self.uiInsertImageAction)
        self.uiAnnotateMenu.addAction(self.uiDrawRectangleAction)
        self.uiAnnotateMenu.addAction(self.uiDrawEllipseAction)
        self.uiToolsMenu.addAction(self.uiVPCSAction)
        self.uiMenuBar.addAction(self.uiFileMenu.menuAction())
        self.uiMenuBar.addAction(self.uiEditMenu.menuAction())
        self.uiMenuBar.addAction(self.uiViewMenu.menuAction())
        self.uiMenuBar.addAction(self.uiControlMenu.menuAction())
        self.uiMenuBar.addAction(self.uiDeviceMenu.menuAction())
        self.uiMenuBar.addAction(self.uiAnnotateMenu.menuAction())
        self.uiMenuBar.addAction(self.uiToolsMenu.menuAction())
        self.uiMenuBar.addAction(self.uiHelpMenu.menuAction())
        self.uiGeneralToolBar.addAction(self.uiNewProjectAction)
        self.uiGeneralToolBar.addAction(self.uiOpenProjectAction)
        self.uiGeneralToolBar.addAction(self.uiSaveProjectAction)
        self.uiBrowsersToolBar.addAction(self.uiBrowseRoutersAction)
        self.uiBrowsersToolBar.addSeparator()
        self.uiBrowsersToolBar.addAction(self.uiBrowseSwitchesAction)
        self.uiBrowsersToolBar.addSeparator()
        self.uiBrowsersToolBar.addAction(self.uiBrowseEndDevicesAction)
        self.uiBrowsersToolBar.addSeparator()
        self.uiBrowsersToolBar.addAction(self.uiBrowseSecurityDevicesAction)
        self.uiBrowsersToolBar.addSeparator()
        self.uiBrowsersToolBar.addAction(self.uiBrowseAllDevicesAction)
        self.uiBrowsersToolBar.addSeparator()
        self.uiBrowsersToolBar.addAction(self.uiAddLinkAction)
        self.uiBrowsersToolBar.addSeparator()
        self.uiControlToolBar.addAction(self.uiSnapshotAction)
        self.uiControlToolBar.addAction(self.uiShowPortNamesAction)
        self.uiControlToolBar.addAction(self.uiConsoleAllAction)
        self.uiControlToolBar.addSeparator()
        self.uiControlToolBar.addAction(self.uiStartAllAction)
        self.uiControlToolBar.addAction(self.uiSuspendAllAction)
        self.uiControlToolBar.addAction(self.uiStopAllAction)
        self.uiControlToolBar.addAction(self.uiReloadAllAction)
        self.uiAnnotationToolBar.addAction(self.uiAddNoteAction)
        self.uiAnnotationToolBar.addAction(self.uiInsertImageAction)
        self.uiAnnotationToolBar.addAction(self.uiDrawRectangleAction)
        self.uiAnnotationToolBar.addAction(self.uiDrawEllipseAction)
        self.uiAnnotationToolBar.addAction(self.uiZoomInAction)
        self.uiAnnotationToolBar.addAction(self.uiZoomOutAction)
        self.uiAnnotationToolBar.addAction(self.uiScreenshotAction)

        self.retranslateUi(MainWindow)
        QtCore.QObject.connect(self.uiQuitAction, QtCore.SIGNAL(_fromUtf8("triggered()")), MainWindow.close)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)
        MainWindow.setTabOrder(self.uiGraphicsView, self.uiNodesView)
        MainWindow.setTabOrder(self.uiNodesView, self.uiConsoleTextEdit)
        MainWindow.setTabOrder(self.uiConsoleTextEdit, self.uiTopologySummaryTreeWidget)

    def retranslateUi(self, MainWindow):
        self.uiEditMenu.setTitle(_translate("MainWindow", "&Edit", None))
        self.uiFileMenu.setTitle(_translate("MainWindow", "&File", None))
        self.uiHelpMenu.setTitle(_translate("MainWindow", "&Help", None))
        self.uiViewMenu.setTitle(_translate("MainWindow", "&View", None))
        self.uiDocksMenu.setTitle(_translate("MainWindow", "Docks", None))
        self.uiControlMenu.setTitle(_translate("MainWindow", "Control", None))
        self.uiAnnotateMenu.setTitle(_translate("MainWindow", "Annotate", None))
        self.uiDeviceMenu.setTitle(_translate("MainWindow", "Device", None))
        self.uiToolsMenu.setTitle(_translate("MainWindow", "&Tools", None))
        self.uiGeneralToolBar.setWindowTitle(_translate("MainWindow", "General", None))
        self.uiNodesDockWidget.setWindowTitle(_translate("MainWindow", "Node Types", None))
        self.uiNodesView.setToolTip(_translate("MainWindow", "Drag a node to the workspace (Press SHIFT while dragging to add multiple identical nodes).", None))
        self.uiNodesView.headerItem().setText(0, _translate("MainWindow", "1", None))
        self.uiBrowsersToolBar.setWindowTitle(_translate("MainWindow", "Devices", None))
        self.uiControlToolBar.setWindowTitle(_translate("MainWindow", "Emulation", None))
        self.uiConsoleDockWidget.setWindowTitle(_translate("MainWindow", "Console", None))
        self.uiAnnotationToolBar.setWindowTitle(_translate("MainWindow", "Drawing", None))
        self.uiTopologySummaryDockWidget.setWindowTitle(_translate("MainWindow", "Topology Summary", None))
        self.uiTopologySummaryTreeWidget.headerItem().setText(0, _translate("MainWindow", "1", None))
        self.uiCloudInspectorDockWidget.setWindowTitle(_translate("MainWindow", "Cloud Inspector", None))
        self.uiAboutAction.setText(_translate("MainWindow", "&About", None))
        self.uiAboutAction.setStatusTip(_translate("MainWindow", "About", None))
        self.uiQuitAction.setText(_translate("MainWindow", "&Quit", None))
        self.uiQuitAction.setStatusTip(_translate("MainWindow", "Quit", None))
        self.uiQuitAction.setShortcut(_translate("MainWindow", "Ctrl+Q", None))
        self.uiOpenProjectAction.setText(_translate("MainWindow", "&Open Project", None))
        self.uiOpenProjectAction.setToolTip(_translate("MainWindow", "Open project", None))
        self.uiOpenProjectAction.setStatusTip(_translate("MainWindow", "Open project", None))
        self.uiOpenProjectAction.setShortcut(_translate("MainWindow", "Ctrl+O", None))
        self.uiSaveProjectAction.setText(_translate("MainWindow", "&Save project", None))
        self.uiSaveProjectAction.setToolTip(_translate("MainWindow", "Save project", None))
        self.uiSaveProjectAction.setStatusTip(_translate("MainWindow", "Save project", None))
        self.uiSaveProjectAction.setShortcut(_translate("MainWindow", "Ctrl+S", None))
        self.uiOnlineHelpAction.setText(_translate("MainWindow", "&Online help", None))
        self.uiOnlineHelpAction.setToolTip(_translate("MainWindow", "Online help", None))
        self.uiOnlineHelpAction.setStatusTip(_translate("MainWindow", "Online Help", None))
        self.uiScreenshotAction.setText(_translate("MainWindow", "Take a screenshot", None))
        self.uiScreenshotAction.setToolTip(_translate("MainWindow", "Take a screenshot", None))
        self.uiScreenshotAction.setStatusTip(_translate("MainWindow", "Take a screenshot", None))
        self.uiStartAllAction.setText(_translate("MainWindow", "Start/Resume all devices", None))
        self.uiStartAllAction.setToolTip(_translate("MainWindow", "Start/Resume all devices", None))
        self.uiStartAllAction.setStatusTip(_translate("MainWindow", "Start/Resume all devices", None))
        self.uiStopAllAction.setText(_translate("MainWindow", "Stop all devices", None))
        self.uiStopAllAction.setToolTip(_translate("MainWindow", "Stop all devices", None))
        self.uiStopAllAction.setStatusTip(_translate("MainWindow", "Stop all devices", None))
        self.uiShowNamesAction.setText(_translate("MainWindow", "Show hostnames", None))
        self.uiShowNamesAction.setToolTip(_translate("MainWindow", "Show hostnames", None))
        self.uiShowNamesAction.setStatusTip(_translate("MainWindow", "Show hostnames", None))
        self.uiConsoleAllAction.setText(_translate("MainWindow", "Console connect to all devices", None))
        self.uiConsoleAllAction.setToolTip(_translate("MainWindow", "Console connect to all devices", None))
        self.uiConsoleAllAction.setStatusTip(_translate("MainWindow", "Console to all devices", None))
        self.uiAboutQtAction.setText(_translate("MainWindow", "About &Qt", None))
        self.uiAboutQtAction.setStatusTip(_translate("MainWindow", "About Qt", None))
        self.uiZoomInAction.setText(_translate("MainWindow", "Zoom in", None))
        self.uiZoomInAction.setToolTip(_translate("MainWindow", "Zoom in", None))
        self.uiZoomInAction.setStatusTip(_translate("MainWindow", "Zoom in", None))
        self.uiZoomInAction.setShortcut(_translate("MainWindow", "Ctrl++", None))
        self.uiZoomOutAction.setText(_translate("MainWindow", "Zoom out", None))
        self.uiZoomOutAction.setToolTip(_translate("MainWindow", "Zoom out", None))
        self.uiZoomOutAction.setStatusTip(_translate("MainWindow", "Zoom out", None))
        self.uiZoomOutAction.setShortcut(_translate("MainWindow", "Ctrl+-", None))
        self.uiZoomResetAction.setText(_translate("MainWindow", "Zoom reset", None))
        self.uiZoomResetAction.setStatusTip(_translate("MainWindow", "Zoom reset", None))
        self.uiZoomResetAction.setShortcut(_translate("MainWindow", "Ctrl+0", None))
        self.uiSelectAllAction.setText(_translate("MainWindow", "Select &all", None))
        self.uiSelectAllAction.setStatusTip(_translate("MainWindow", "Select All", None))
        self.uiSelectAllAction.setShortcut(_translate("MainWindow", "Ctrl+A", None))
        self.uiSelectNoneAction.setText(_translate("MainWindow", "Select &none", None))
        self.uiSelectNoneAction.setStatusTip(_translate("MainWindow", "Select None", None))
        self.uiSelectNoneAction.setShortcut(_translate("MainWindow", "Ctrl+Shift+A", None))
        self.uiPreferencesAction.setText(_translate("MainWindow", "&Preferences...", None))
        self.uiPreferencesAction.setStatusTip(_translate("MainWindow", "Preferences", None))
        self.uiPreferencesAction.setShortcut(_translate("MainWindow", "Ctrl+Shift+P", None))
        self.uiSuspendAllAction.setText(_translate("MainWindow", "Suspend all devices", None))
        self.uiSuspendAllAction.setToolTip(_translate("MainWindow", "Suspend all devices", None))
        self.uiSuspendAllAction.setStatusTip(_translate("MainWindow", "Suspend all devices", None))
        self.uiAddNoteAction.setText(_translate("MainWindow", "Add note", None))
        self.uiAddNoteAction.setToolTip(_translate("MainWindow", "Add a note", None))
        self.uiAddNoteAction.setStatusTip(_translate("MainWindow", "Add a note", None))
        self.uiNewProjectAction.setText(_translate("MainWindow", "&New blank project", None))
        self.uiNewProjectAction.setIconText(_translate("MainWindow", "New Project", None))
        self.uiNewProjectAction.setToolTip(_translate("MainWindow", "New blank project", None))
        self.uiNewProjectAction.setStatusTip(_translate("MainWindow", "New blank project", None))
        self.uiNewProjectAction.setShortcut(_translate("MainWindow", "Ctrl+N", None))
        self.uiImportExportConfigsAction.setText(_translate("MainWindow", "&Import/Export device configs", None))
        self.uiImportExportConfigsAction.setToolTip(_translate("MainWindow", "Import/Export device configs", None))
        self.uiImportExportConfigsAction.setStatusTip(_translate("MainWindow", "Import/Export device configs", None))
        self.uiInsertImageAction.setText(_translate("MainWindow", "Insert picture", None))
        self.uiInsertImageAction.setToolTip(_translate("MainWindow", "Insert a picture", None))
        self.uiInsertImageAction.setStatusTip(_translate("MainWindow", "Insert a picture", None))
        self.uiDrawRectangleAction.setText(_translate("MainWindow", "Draw rectangle", None))
        self.uiDrawRectangleAction.setToolTip(_translate("MainWindow", "Draw a rectangle", None))
        self.uiDrawRectangleAction.setStatusTip(_translate("MainWindow", "Draw a rectangle", None))
        self.uiDrawEllipseAction.setText(_translate("MainWindow", "Draw ellipse", None))
        self.uiDrawEllipseAction.setToolTip(_translate("MainWindow", "Draw an ellipse", None))
        self.uiDrawEllipseAction.setStatusTip(_translate("MainWindow", "Draw an ellipse", None))
        self.uiShowPortNamesAction.setText(_translate("MainWindow", "Show/Hide interface labels", None))
        self.uiShowPortNamesAction.setToolTip(_translate("MainWindow", "Show/Hide interface labels", None))
        self.uiShowPortNamesAction.setStatusTip(_translate("MainWindow", "Show/Hide interface labels", None))
        self.uiSnapshotAction.setText(_translate("MainWindow", "Manage snapshots", None))
        self.uiSnapshotAction.setToolTip(_translate("MainWindow", "Manage snapshots", None))
        self.uiSnapshotAction.setStatusTip(_translate("MainWindow", "Manage snapshots", None))
        self.uiShowLayersAction.setText(_translate("MainWindow", "Show layers", None))
        self.uiShowLayersAction.setStatusTip(_translate("MainWindow", "Show layers", None))
        self.uiSaveProjectAsAction.setText(_translate("MainWindow", "&Save project as…", None))
        self.uiSaveProjectAsAction.setToolTip(_translate("MainWindow", "Save project as...", None))
        self.uiSaveProjectAsAction.setStatusTip(_translate("MainWindow", "Save project as...", None))
        self.uiReloadAllAction.setText(_translate("MainWindow", "Reload all devices", None))
        self.uiReloadAllAction.setToolTip(_translate("MainWindow", "Reload all devices", None))
        self.uiReloadAllAction.setStatusTip(_translate("MainWindow", "Reload all devices", None))
        self.uiAuxConsoleAllAction.setText(_translate("MainWindow", "Console connect via AUX to all devices", None))
        self.uiAuxConsoleAllAction.setToolTip(_translate("MainWindow", "Console connect via AUX to all devices", None))
        self.uiAuxConsoleAllAction.setStatusTip(_translate("MainWindow", "Console AUX to all devices", None))
        self.uiResetPortLabelsAction.setText(_translate("MainWindow", "Reset interface labels", None))
        self.uiResetPortLabelsAction.setToolTip(_translate("MainWindow", "Reset interface labels", None))
        self.uiResetPortLabelsAction.setStatusTip(_translate("MainWindow", "Reset Interface Labels", None))
        self.uiCheckForUpdateAction.setText(_translate("MainWindow", "Check for Update", None))
        self.uiCheckForUpdateAction.setStatusTip(_translate("MainWindow", "Check for Update", None))
        self.uiEnergySavingStyleAction.setText(_translate("MainWindow", "Energy Saving", None))
        self.uiEnergySavingStyleAction.setStatusTip(_translate("MainWindow", "Energy Saving Mode", None))
        self.uiDefaultStyleAction.setText(_translate("MainWindow", "Default", None))
        self.uiBrowseRoutersAction.setText(_translate("MainWindow", "Browse Routers", None))
        self.uiBrowseRoutersAction.setIconText(_translate("MainWindow", "Browse Routers", None))
        self.uiBrowseRoutersAction.setToolTip(_translate("MainWindow", "Browse Routers", None))
        self.uiBrowseRoutersAction.setStatusTip(_translate("MainWindow", "Browse Routers", None))
        self.uiBrowseSwitchesAction.setText(_translate("MainWindow", "Browse Switches", None))
        self.uiBrowseSwitchesAction.setIconText(_translate("MainWindow", "Browse Switches", None))
        self.uiBrowseSwitchesAction.setToolTip(_translate("MainWindow", "Browse Switches", None))
        self.uiBrowseSwitchesAction.setStatusTip(_translate("MainWindow", "Browse Switches", None))
        self.uiBrowseEndDevicesAction.setText(_translate("MainWindow", "Browse End Devices", None))
        self.uiBrowseEndDevicesAction.setIconText(_translate("MainWindow", "Browse End Devices", None))
        self.uiBrowseEndDevicesAction.setToolTip(_translate("MainWindow", "Browse End Devices", None))
        self.uiBrowseEndDevicesAction.setStatusTip(_translate("MainWindow", "Browse End Devices", None))
        self.uiBrowseSecurityDevicesAction.setText(_translate("MainWindow", "Browse Security Devices", None))
        self.uiBrowseSecurityDevicesAction.setIconText(_translate("MainWindow", "Browse Security Devices", None))
        self.uiBrowseSecurityDevicesAction.setToolTip(_translate("MainWindow", "Browse Security Devices", None))
        self.uiBrowseSecurityDevicesAction.setStatusTip(_translate("MainWindow", "Browse Security Devices", None))
        self.uiBrowseAllDevicesAction.setText(_translate("MainWindow", "Browse all devices", None))
        self.uiBrowseAllDevicesAction.setToolTip(_translate("MainWindow", "Browse all devices", None))
        self.uiBrowseAllDevicesAction.setStatusTip(_translate("MainWindow", "Browse all devices", None))
        self.uiAddLinkAction.setText(_translate("MainWindow", "Add a link", None))
        self.uiAddLinkAction.setToolTip(_translate("MainWindow", "Add a link", None))
        self.uiAddLinkAction.setStatusTip(_translate("MainWindow", "Add a link", None))
        self.uiGettingStartedAction.setText(_translate("MainWindow", "Getting started", None))
        self.uiGettingStartedAction.setToolTip(_translate("MainWindow", "Show GNS3 news", None))
        self.uiLabInstructionsAction.setText(_translate("MainWindow", "Lab instructions", None))
        self.uiFitInViewAction.setText(_translate("MainWindow", "Fit in view", None))
        self.uiExportProjectAction.setText(_translate("MainWindow", "Backup project to cloud", None))
        self.uiImportProjectAction.setText(_translate("MainWindow", "Restore backup from cloud", None))
        self.uiMoveLocalProjectToCloudAction.setText(_translate("MainWindow", "Move local project to cloud", None))
        self.uiMoveCloudProjectToLocalAction.setText(_translate("MainWindow", "Move cloud project to local", None))
        self.uiDarkStyleAction.setText(_translate("MainWindow", "Dark Style", None))
        self.uiActionFullscreen.setText(_translate("MainWindow", "Fullscreen", None))
        self.uiActionFullscreen.setShortcut(_translate("MainWindow", "Ctrl+F", None))
        self.uiVPCSAction.setText(_translate("MainWindow", "&VPCS multi-host", None))

from ..cloud_inspector_view import CloudInspectorView
from ..console_view import ConsoleView
from ..nodes_view import NodesView
from ..graphics_view import GraphicsView
from ..topology_summary_view import TopologySummaryView
from . import resources_rc
