# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/grossmj/PycharmProjects/gns3-gui/gns3/modules/dynamips/ui/ios_router_configuration_page.ui'
#
# Created: Sat Mar 14 16:29:27 2015
#      by: PyQt4 UI code generator 4.10.4
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_iosRouterConfigPageWidget(object):
    def setupUi(self, iosRouterConfigPageWidget):
        iosRouterConfigPageWidget.setObjectName(_fromUtf8("iosRouterConfigPageWidget"))
        iosRouterConfigPageWidget.resize(449, 491)
        self.vboxlayout = QtGui.QVBoxLayout(iosRouterConfigPageWidget)
        self.vboxlayout.setObjectName(_fromUtf8("vboxlayout"))
        self.uiTabWidget = QtGui.QTabWidget(iosRouterConfigPageWidget)
        self.uiTabWidget.setObjectName(_fromUtf8("uiTabWidget"))
        self.uiGeneralPageWidget = QtGui.QWidget()
        self.uiGeneralPageWidget.setObjectName(_fromUtf8("uiGeneralPageWidget"))
        self.gridLayout_2 = QtGui.QGridLayout(self.uiGeneralPageWidget)
        self.gridLayout_2.setObjectName(_fromUtf8("gridLayout_2"))
        self.uiNameLabel = QtGui.QLabel(self.uiGeneralPageWidget)
        self.uiNameLabel.setObjectName(_fromUtf8("uiNameLabel"))
        self.gridLayout_2.addWidget(self.uiNameLabel, 0, 0, 1, 1)
        self.uiNameLineEdit = QtGui.QLineEdit(self.uiGeneralPageWidget)
        self.uiNameLineEdit.setObjectName(_fromUtf8("uiNameLineEdit"))
        self.gridLayout_2.addWidget(self.uiNameLineEdit, 0, 1, 1, 1)
        self.uiPlatformLabel = QtGui.QLabel(self.uiGeneralPageWidget)
        self.uiPlatformLabel.setObjectName(_fromUtf8("uiPlatformLabel"))
        self.gridLayout_2.addWidget(self.uiPlatformLabel, 1, 0, 1, 1)
        self.uiPlatformTextLabel = QtGui.QLabel(self.uiGeneralPageWidget)
        self.uiPlatformTextLabel.setText(_fromUtf8(""))
        self.uiPlatformTextLabel.setObjectName(_fromUtf8("uiPlatformTextLabel"))
        self.gridLayout_2.addWidget(self.uiPlatformTextLabel, 1, 1, 1, 1)
        self.uiChassisLabel = QtGui.QLabel(self.uiGeneralPageWidget)
        self.uiChassisLabel.setObjectName(_fromUtf8("uiChassisLabel"))
        self.gridLayout_2.addWidget(self.uiChassisLabel, 2, 0, 1, 1)
        self.uiChassisTextLabel = QtGui.QLabel(self.uiGeneralPageWidget)
        self.uiChassisTextLabel.setText(_fromUtf8(""))
        self.uiChassisTextLabel.setObjectName(_fromUtf8("uiChassisTextLabel"))
        self.gridLayout_2.addWidget(self.uiChassisTextLabel, 2, 1, 1, 1)
        self.uiIOSImageLabel = QtGui.QLabel(self.uiGeneralPageWidget)
        self.uiIOSImageLabel.setObjectName(_fromUtf8("uiIOSImageLabel"))
        self.gridLayout_2.addWidget(self.uiIOSImageLabel, 3, 0, 1, 1)
        self.horizontalLayout_5 = QtGui.QHBoxLayout()
        self.horizontalLayout_5.setObjectName(_fromUtf8("horizontalLayout_5"))
        self.uiIOSImageLineEdit = QtGui.QLineEdit(self.uiGeneralPageWidget)
        self.uiIOSImageLineEdit.setObjectName(_fromUtf8("uiIOSImageLineEdit"))
        self.horizontalLayout_5.addWidget(self.uiIOSImageLineEdit)
        self.uiIOSImageToolButton = QtGui.QToolButton(self.uiGeneralPageWidget)
        self.uiIOSImageToolButton.setToolButtonStyle(QtCore.Qt.ToolButtonTextOnly)
        self.uiIOSImageToolButton.setObjectName(_fromUtf8("uiIOSImageToolButton"))
        self.horizontalLayout_5.addWidget(self.uiIOSImageToolButton)
        self.gridLayout_2.addLayout(self.horizontalLayout_5, 3, 1, 1, 1)
        self.uiStartupConfigLabel = QtGui.QLabel(self.uiGeneralPageWidget)
        self.uiStartupConfigLabel.setObjectName(_fromUtf8("uiStartupConfigLabel"))
        self.gridLayout_2.addWidget(self.uiStartupConfigLabel, 4, 0, 1, 1)
        self.horizontalLayout_4 = QtGui.QHBoxLayout()
        self.horizontalLayout_4.setObjectName(_fromUtf8("horizontalLayout_4"))
        self.uiStartupConfigLineEdit = QtGui.QLineEdit(self.uiGeneralPageWidget)
        self.uiStartupConfigLineEdit.setObjectName(_fromUtf8("uiStartupConfigLineEdit"))
        self.horizontalLayout_4.addWidget(self.uiStartupConfigLineEdit)
        self.uiStartupConfigToolButton = QtGui.QToolButton(self.uiGeneralPageWidget)
        self.uiStartupConfigToolButton.setToolButtonStyle(QtCore.Qt.ToolButtonTextOnly)
        self.uiStartupConfigToolButton.setObjectName(_fromUtf8("uiStartupConfigToolButton"))
        self.horizontalLayout_4.addWidget(self.uiStartupConfigToolButton)
        self.gridLayout_2.addLayout(self.horizontalLayout_4, 4, 1, 1, 1)
        self.uiPrivateConfigLabel = QtGui.QLabel(self.uiGeneralPageWidget)
        self.uiPrivateConfigLabel.setObjectName(_fromUtf8("uiPrivateConfigLabel"))
        self.gridLayout_2.addWidget(self.uiPrivateConfigLabel, 5, 0, 1, 1)
        self.horizontalLayout_6 = QtGui.QHBoxLayout()
        self.horizontalLayout_6.setObjectName(_fromUtf8("horizontalLayout_6"))
        self.uiPrivateConfigLineEdit = QtGui.QLineEdit(self.uiGeneralPageWidget)
        self.uiPrivateConfigLineEdit.setObjectName(_fromUtf8("uiPrivateConfigLineEdit"))
        self.horizontalLayout_6.addWidget(self.uiPrivateConfigLineEdit)
        self.uiPrivateConfigToolButton = QtGui.QToolButton(self.uiGeneralPageWidget)
        self.uiPrivateConfigToolButton.setToolButtonStyle(QtCore.Qt.ToolButtonTextOnly)
        self.uiPrivateConfigToolButton.setObjectName(_fromUtf8("uiPrivateConfigToolButton"))
        self.horizontalLayout_6.addWidget(self.uiPrivateConfigToolButton)
        self.gridLayout_2.addLayout(self.horizontalLayout_6, 5, 1, 1, 1)
        self.uiConsolePortLabel = QtGui.QLabel(self.uiGeneralPageWidget)
        self.uiConsolePortLabel.setObjectName(_fromUtf8("uiConsolePortLabel"))
        self.gridLayout_2.addWidget(self.uiConsolePortLabel, 6, 0, 1, 1)
        self.uiConsolePortSpinBox = QtGui.QSpinBox(self.uiGeneralPageWidget)
        self.uiConsolePortSpinBox.setMaximum(65535)
        self.uiConsolePortSpinBox.setObjectName(_fromUtf8("uiConsolePortSpinBox"))
        self.gridLayout_2.addWidget(self.uiConsolePortSpinBox, 6, 1, 1, 1)
        self.uiAuxPortLabel = QtGui.QLabel(self.uiGeneralPageWidget)
        self.uiAuxPortLabel.setObjectName(_fromUtf8("uiAuxPortLabel"))
        self.gridLayout_2.addWidget(self.uiAuxPortLabel, 7, 0, 1, 1)
        self.uiAuxPortSpinBox = QtGui.QSpinBox(self.uiGeneralPageWidget)
        self.uiAuxPortSpinBox.setMaximum(65535)
        self.uiAuxPortSpinBox.setObjectName(_fromUtf8("uiAuxPortSpinBox"))
        self.gridLayout_2.addWidget(self.uiAuxPortSpinBox, 7, 1, 1, 1)
        self.uiMidplaneLabel = QtGui.QLabel(self.uiGeneralPageWidget)
        self.uiMidplaneLabel.setObjectName(_fromUtf8("uiMidplaneLabel"))
        self.gridLayout_2.addWidget(self.uiMidplaneLabel, 8, 0, 1, 1)
        self.uiMidplaneComboBox = QtGui.QComboBox(self.uiGeneralPageWidget)
        self.uiMidplaneComboBox.setEnabled(True)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiMidplaneComboBox.sizePolicy().hasHeightForWidth())
        self.uiMidplaneComboBox.setSizePolicy(sizePolicy)
        self.uiMidplaneComboBox.setObjectName(_fromUtf8("uiMidplaneComboBox"))
        self.gridLayout_2.addWidget(self.uiMidplaneComboBox, 8, 1, 1, 1)
        self.uiNPELabel = QtGui.QLabel(self.uiGeneralPageWidget)
        self.uiNPELabel.setObjectName(_fromUtf8("uiNPELabel"))
        self.gridLayout_2.addWidget(self.uiNPELabel, 9, 0, 1, 1)
        self.uiNPEComboBox = QtGui.QComboBox(self.uiGeneralPageWidget)
        self.uiNPEComboBox.setEnabled(True)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiNPEComboBox.sizePolicy().hasHeightForWidth())
        self.uiNPEComboBox.setSizePolicy(sizePolicy)
        self.uiNPEComboBox.setObjectName(_fromUtf8("uiNPEComboBox"))
        self.gridLayout_2.addWidget(self.uiNPEComboBox, 9, 1, 1, 1)
        spacerItem = QtGui.QSpacerItem(263, 151, QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Expanding)
        self.gridLayout_2.addItem(spacerItem, 10, 1, 1, 1)
        self.uiTabWidget.addTab(self.uiGeneralPageWidget, _fromUtf8(""))
        self.uiMemoriesPageWidget = QtGui.QWidget()
        self.uiMemoriesPageWidget.setObjectName(_fromUtf8("uiMemoriesPageWidget"))
        self.verticalLayout_2 = QtGui.QVBoxLayout(self.uiMemoriesPageWidget)
        self.verticalLayout_2.setObjectName(_fromUtf8("verticalLayout_2"))
        self.uiMemoriesGroupBox = QtGui.QGroupBox(self.uiMemoriesPageWidget)
        self.uiMemoriesGroupBox.setObjectName(_fromUtf8("uiMemoriesGroupBox"))
        self.gridLayout_5 = QtGui.QGridLayout(self.uiMemoriesGroupBox)
        self.gridLayout_5.setObjectName(_fromUtf8("gridLayout_5"))
        self.uiRamLabel = QtGui.QLabel(self.uiMemoriesGroupBox)
        self.uiRamLabel.setObjectName(_fromUtf8("uiRamLabel"))
        self.gridLayout_5.addWidget(self.uiRamLabel, 0, 0, 1, 1)
        self.uiRamSpinBox = QtGui.QSpinBox(self.uiMemoriesGroupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiRamSpinBox.sizePolicy().hasHeightForWidth())
        self.uiRamSpinBox.setSizePolicy(sizePolicy)
        self.uiRamSpinBox.setMinimum(32)
        self.uiRamSpinBox.setMaximum(65535)
        self.uiRamSpinBox.setSingleStep(32)
        self.uiRamSpinBox.setProperty("value", 128)
        self.uiRamSpinBox.setObjectName(_fromUtf8("uiRamSpinBox"))
        self.gridLayout_5.addWidget(self.uiRamSpinBox, 0, 1, 1, 1)
        self.uiNvramLabel = QtGui.QLabel(self.uiMemoriesGroupBox)
        self.uiNvramLabel.setObjectName(_fromUtf8("uiNvramLabel"))
        self.gridLayout_5.addWidget(self.uiNvramLabel, 1, 0, 1, 1)
        self.uiNvramSpinBox = QtGui.QSpinBox(self.uiMemoriesGroupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiNvramSpinBox.sizePolicy().hasHeightForWidth())
        self.uiNvramSpinBox.setSizePolicy(sizePolicy)
        self.uiNvramSpinBox.setMinimum(32)
        self.uiNvramSpinBox.setMaximum(65535)
        self.uiNvramSpinBox.setSingleStep(32)
        self.uiNvramSpinBox.setProperty("value", 128)
        self.uiNvramSpinBox.setObjectName(_fromUtf8("uiNvramSpinBox"))
        self.gridLayout_5.addWidget(self.uiNvramSpinBox, 1, 1, 1, 1)
        self.uiIomemLabel = QtGui.QLabel(self.uiMemoriesGroupBox)
        self.uiIomemLabel.setObjectName(_fromUtf8("uiIomemLabel"))
        self.gridLayout_5.addWidget(self.uiIomemLabel, 2, 0, 1, 1)
        self.uiIomemSpinBox = QtGui.QSpinBox(self.uiMemoriesGroupBox)
        self.uiIomemSpinBox.setEnabled(True)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiIomemSpinBox.sizePolicy().hasHeightForWidth())
        self.uiIomemSpinBox.setSizePolicy(sizePolicy)
        self.uiIomemSpinBox.setMaximum(100)
        self.uiIomemSpinBox.setSingleStep(5)
        self.uiIomemSpinBox.setProperty("value", 5)
        self.uiIomemSpinBox.setObjectName(_fromUtf8("uiIomemSpinBox"))
        self.gridLayout_5.addWidget(self.uiIomemSpinBox, 2, 1, 1, 1)
        self.verticalLayout_2.addWidget(self.uiMemoriesGroupBox)
        self.uiDisksGroupBox = QtGui.QGroupBox(self.uiMemoriesPageWidget)
        self.uiDisksGroupBox.setObjectName(_fromUtf8("uiDisksGroupBox"))
        self.gridlayout = QtGui.QGridLayout(self.uiDisksGroupBox)
        self.gridlayout.setObjectName(_fromUtf8("gridlayout"))
        self.uiDisk0Label = QtGui.QLabel(self.uiDisksGroupBox)
        self.uiDisk0Label.setObjectName(_fromUtf8("uiDisk0Label"))
        self.gridlayout.addWidget(self.uiDisk0Label, 0, 0, 1, 1)
        self.uiDisk0SpinBox = QtGui.QSpinBox(self.uiDisksGroupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiDisk0SpinBox.sizePolicy().hasHeightForWidth())
        self.uiDisk0SpinBox.setSizePolicy(sizePolicy)
        self.uiDisk0SpinBox.setMaximum(99999)
        self.uiDisk0SpinBox.setSingleStep(4)
        self.uiDisk0SpinBox.setObjectName(_fromUtf8("uiDisk0SpinBox"))
        self.gridlayout.addWidget(self.uiDisk0SpinBox, 0, 1, 1, 1)
        self.uiDisk1Label = QtGui.QLabel(self.uiDisksGroupBox)
        self.uiDisk1Label.setObjectName(_fromUtf8("uiDisk1Label"))
        self.gridlayout.addWidget(self.uiDisk1Label, 1, 0, 1, 1)
        self.uiDisk1SpinBox = QtGui.QSpinBox(self.uiDisksGroupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiDisk1SpinBox.sizePolicy().hasHeightForWidth())
        self.uiDisk1SpinBox.setSizePolicy(sizePolicy)
        self.uiDisk1SpinBox.setMaximum(99999)
        self.uiDisk1SpinBox.setSingleStep(4)
        self.uiDisk1SpinBox.setObjectName(_fromUtf8("uiDisk1SpinBox"))
        self.gridlayout.addWidget(self.uiDisk1SpinBox, 1, 1, 1, 1)
        self.verticalLayout_2.addWidget(self.uiDisksGroupBox)
        spacerItem1 = QtGui.QSpacerItem(20, 21, QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem1)
        self.uiTabWidget.addTab(self.uiMemoriesPageWidget, _fromUtf8(""))
        self.uiSlotsPageWidget = QtGui.QWidget()
        self.uiSlotsPageWidget.setObjectName(_fromUtf8("uiSlotsPageWidget"))
        self.verticalLayout = QtGui.QVBoxLayout(self.uiSlotsPageWidget)
        self.verticalLayout.setObjectName(_fromUtf8("verticalLayout"))
        self.uiAdaptersGroupBox = QtGui.QGroupBox(self.uiSlotsPageWidget)
        self.uiAdaptersGroupBox.setObjectName(_fromUtf8("uiAdaptersGroupBox"))
        self.gridLayout = QtGui.QGridLayout(self.uiAdaptersGroupBox)
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.uiSlot1comboBox = QtGui.QComboBox(self.uiAdaptersGroupBox)
        self.uiSlot1comboBox.setObjectName(_fromUtf8("uiSlot1comboBox"))
        self.gridLayout.addWidget(self.uiSlot1comboBox, 1, 1, 1, 1)
        self.uiSlot0Label = QtGui.QLabel(self.uiAdaptersGroupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiSlot0Label.sizePolicy().hasHeightForWidth())
        self.uiSlot0Label.setSizePolicy(sizePolicy)
        self.uiSlot0Label.setObjectName(_fromUtf8("uiSlot0Label"))
        self.gridLayout.addWidget(self.uiSlot0Label, 0, 0, 1, 1)
        self.uiSlot0comboBox = QtGui.QComboBox(self.uiAdaptersGroupBox)
        self.uiSlot0comboBox.setObjectName(_fromUtf8("uiSlot0comboBox"))
        self.gridLayout.addWidget(self.uiSlot0comboBox, 0, 1, 1, 1)
        self.uiSlot1Label = QtGui.QLabel(self.uiAdaptersGroupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiSlot1Label.sizePolicy().hasHeightForWidth())
        self.uiSlot1Label.setSizePolicy(sizePolicy)
        self.uiSlot1Label.setObjectName(_fromUtf8("uiSlot1Label"))
        self.gridLayout.addWidget(self.uiSlot1Label, 1, 0, 1, 1)
        self.uiSlot2Label = QtGui.QLabel(self.uiAdaptersGroupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiSlot2Label.sizePolicy().hasHeightForWidth())
        self.uiSlot2Label.setSizePolicy(sizePolicy)
        self.uiSlot2Label.setObjectName(_fromUtf8("uiSlot2Label"))
        self.gridLayout.addWidget(self.uiSlot2Label, 2, 0, 1, 1)
        self.uiSlot2comboBox = QtGui.QComboBox(self.uiAdaptersGroupBox)
        self.uiSlot2comboBox.setObjectName(_fromUtf8("uiSlot2comboBox"))
        self.gridLayout.addWidget(self.uiSlot2comboBox, 2, 1, 1, 1)
        self.uiSlot3Label = QtGui.QLabel(self.uiAdaptersGroupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiSlot3Label.sizePolicy().hasHeightForWidth())
        self.uiSlot3Label.setSizePolicy(sizePolicy)
        self.uiSlot3Label.setObjectName(_fromUtf8("uiSlot3Label"))
        self.gridLayout.addWidget(self.uiSlot3Label, 3, 0, 1, 1)
        self.uiSlot3comboBox = QtGui.QComboBox(self.uiAdaptersGroupBox)
        self.uiSlot3comboBox.setObjectName(_fromUtf8("uiSlot3comboBox"))
        self.gridLayout.addWidget(self.uiSlot3comboBox, 3, 1, 1, 1)
        self.uiSlot4Label = QtGui.QLabel(self.uiAdaptersGroupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiSlot4Label.sizePolicy().hasHeightForWidth())
        self.uiSlot4Label.setSizePolicy(sizePolicy)
        self.uiSlot4Label.setObjectName(_fromUtf8("uiSlot4Label"))
        self.gridLayout.addWidget(self.uiSlot4Label, 4, 0, 1, 1)
        self.uiSlot4comboBox = QtGui.QComboBox(self.uiAdaptersGroupBox)
        self.uiSlot4comboBox.setObjectName(_fromUtf8("uiSlot4comboBox"))
        self.gridLayout.addWidget(self.uiSlot4comboBox, 4, 1, 1, 1)
        self.uiSlot5Label = QtGui.QLabel(self.uiAdaptersGroupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiSlot5Label.sizePolicy().hasHeightForWidth())
        self.uiSlot5Label.setSizePolicy(sizePolicy)
        self.uiSlot5Label.setObjectName(_fromUtf8("uiSlot5Label"))
        self.gridLayout.addWidget(self.uiSlot5Label, 5, 0, 1, 1)
        self.uiSlot5comboBox = QtGui.QComboBox(self.uiAdaptersGroupBox)
        self.uiSlot5comboBox.setObjectName(_fromUtf8("uiSlot5comboBox"))
        self.gridLayout.addWidget(self.uiSlot5comboBox, 5, 1, 1, 1)
        self.uiSlot6Label = QtGui.QLabel(self.uiAdaptersGroupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiSlot6Label.sizePolicy().hasHeightForWidth())
        self.uiSlot6Label.setSizePolicy(sizePolicy)
        self.uiSlot6Label.setObjectName(_fromUtf8("uiSlot6Label"))
        self.gridLayout.addWidget(self.uiSlot6Label, 6, 0, 1, 1)
        self.uiSlot6comboBox = QtGui.QComboBox(self.uiAdaptersGroupBox)
        self.uiSlot6comboBox.setObjectName(_fromUtf8("uiSlot6comboBox"))
        self.gridLayout.addWidget(self.uiSlot6comboBox, 6, 1, 1, 1)
        self.verticalLayout.addWidget(self.uiAdaptersGroupBox)
        self.uiWicsGroupBox = QtGui.QGroupBox(self.uiSlotsPageWidget)
        self.uiWicsGroupBox.setObjectName(_fromUtf8("uiWicsGroupBox"))
        self.gridlayout1 = QtGui.QGridLayout(self.uiWicsGroupBox)
        self.gridlayout1.setObjectName(_fromUtf8("gridlayout1"))
        self.uiWic0Label = QtGui.QLabel(self.uiWicsGroupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiWic0Label.sizePolicy().hasHeightForWidth())
        self.uiWic0Label.setSizePolicy(sizePolicy)
        self.uiWic0Label.setObjectName(_fromUtf8("uiWic0Label"))
        self.gridlayout1.addWidget(self.uiWic0Label, 0, 0, 1, 1)
        self.uiWic0comboBox = QtGui.QComboBox(self.uiWicsGroupBox)
        self.uiWic0comboBox.setObjectName(_fromUtf8("uiWic0comboBox"))
        self.gridlayout1.addWidget(self.uiWic0comboBox, 0, 1, 1, 1)
        self.uiWic1Label = QtGui.QLabel(self.uiWicsGroupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiWic1Label.sizePolicy().hasHeightForWidth())
        self.uiWic1Label.setSizePolicy(sizePolicy)
        self.uiWic1Label.setObjectName(_fromUtf8("uiWic1Label"))
        self.gridlayout1.addWidget(self.uiWic1Label, 1, 0, 1, 1)
        self.uiWic1comboBox = QtGui.QComboBox(self.uiWicsGroupBox)
        self.uiWic1comboBox.setObjectName(_fromUtf8("uiWic1comboBox"))
        self.gridlayout1.addWidget(self.uiWic1comboBox, 1, 1, 1, 1)
        self.uiWic2Label = QtGui.QLabel(self.uiWicsGroupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiWic2Label.sizePolicy().hasHeightForWidth())
        self.uiWic2Label.setSizePolicy(sizePolicy)
        self.uiWic2Label.setObjectName(_fromUtf8("uiWic2Label"))
        self.gridlayout1.addWidget(self.uiWic2Label, 2, 0, 1, 1)
        self.uiWic2comboBox = QtGui.QComboBox(self.uiWicsGroupBox)
        self.uiWic2comboBox.setObjectName(_fromUtf8("uiWic2comboBox"))
        self.gridlayout1.addWidget(self.uiWic2comboBox, 2, 1, 1, 1)
        self.verticalLayout.addWidget(self.uiWicsGroupBox)
        spacerItem2 = QtGui.QSpacerItem(325, 31, QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem2)
        self.uiTabWidget.addTab(self.uiSlotsPageWidget, _fromUtf8(""))
        self.uiAdvancedPageWidget = QtGui.QWidget()
        self.uiAdvancedPageWidget.setObjectName(_fromUtf8("uiAdvancedPageWidget"))
        self.verticalLayout_4 = QtGui.QVBoxLayout(self.uiAdvancedPageWidget)
        self.verticalLayout_4.setObjectName(_fromUtf8("verticalLayout_4"))
        self.uiSystemGroupBox = QtGui.QGroupBox(self.uiAdvancedPageWidget)
        self.uiSystemGroupBox.setObjectName(_fromUtf8("uiSystemGroupBox"))
        self.gridLayout_6 = QtGui.QGridLayout(self.uiSystemGroupBox)
        self.gridLayout_6.setObjectName(_fromUtf8("gridLayout_6"))
        self.uiSystemIdLineEdit = QtGui.QLineEdit(self.uiSystemGroupBox)
        self.uiSystemIdLineEdit.setObjectName(_fromUtf8("uiSystemIdLineEdit"))
        self.gridLayout_6.addWidget(self.uiSystemIdLineEdit, 0, 1, 1, 1)
        self.label = QtGui.QLabel(self.uiSystemGroupBox)
        self.label.setObjectName(_fromUtf8("label"))
        self.gridLayout_6.addWidget(self.label, 0, 0, 1, 1)
        self.uiBaseMacLabel = QtGui.QLabel(self.uiSystemGroupBox)
        self.uiBaseMacLabel.setObjectName(_fromUtf8("uiBaseMacLabel"))
        self.gridLayout_6.addWidget(self.uiBaseMacLabel, 1, 0, 1, 1)
        self.uiBaseMACLineEdit = QtGui.QLineEdit(self.uiSystemGroupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiBaseMACLineEdit.sizePolicy().hasHeightForWidth())
        self.uiBaseMACLineEdit.setSizePolicy(sizePolicy)
        self.uiBaseMACLineEdit.setText(_fromUtf8(""))
        self.uiBaseMACLineEdit.setObjectName(_fromUtf8("uiBaseMACLineEdit"))
        self.gridLayout_6.addWidget(self.uiBaseMACLineEdit, 1, 1, 1, 1)
        self.verticalLayout_4.addWidget(self.uiSystemGroupBox)
        self.uiOptimizationsGroupBox = QtGui.QGroupBox(self.uiAdvancedPageWidget)
        self.uiOptimizationsGroupBox.setObjectName(_fromUtf8("uiOptimizationsGroupBox"))
        self.gridLayout_4 = QtGui.QGridLayout(self.uiOptimizationsGroupBox)
        self.gridLayout_4.setObjectName(_fromUtf8("gridLayout_4"))
        self.uiExecAreaLabel = QtGui.QLabel(self.uiOptimizationsGroupBox)
        self.uiExecAreaLabel.setObjectName(_fromUtf8("uiExecAreaLabel"))
        self.gridLayout_4.addWidget(self.uiExecAreaLabel, 3, 0, 1, 1)
        self.uiExecAreaSpinBox = QtGui.QSpinBox(self.uiOptimizationsGroupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiExecAreaSpinBox.sizePolicy().hasHeightForWidth())
        self.uiExecAreaSpinBox.setSizePolicy(sizePolicy)
        self.uiExecAreaSpinBox.setMaximum(4096)
        self.uiExecAreaSpinBox.setSingleStep(4)
        self.uiExecAreaSpinBox.setProperty("value", 64)
        self.uiExecAreaSpinBox.setObjectName(_fromUtf8("uiExecAreaSpinBox"))
        self.gridLayout_4.addWidget(self.uiExecAreaSpinBox, 3, 1, 1, 1)
        self.uiSparseMemoryCheckBox = QtGui.QCheckBox(self.uiOptimizationsGroupBox)
        self.uiSparseMemoryCheckBox.setChecked(False)
        self.uiSparseMemoryCheckBox.setObjectName(_fromUtf8("uiSparseMemoryCheckBox"))
        self.gridLayout_4.addWidget(self.uiSparseMemoryCheckBox, 5, 0, 1, 2)
        self.uiIdlepcLabel = QtGui.QLabel(self.uiOptimizationsGroupBox)
        self.uiIdlepcLabel.setObjectName(_fromUtf8("uiIdlepcLabel"))
        self.gridLayout_4.addWidget(self.uiIdlepcLabel, 0, 0, 1, 1)
        self.uiIdlepcLineEdit = QtGui.QLineEdit(self.uiOptimizationsGroupBox)
        self.uiIdlepcLineEdit.setObjectName(_fromUtf8("uiIdlepcLineEdit"))
        self.gridLayout_4.addWidget(self.uiIdlepcLineEdit, 0, 1, 1, 1)
        self.uiIdlemaxLabel = QtGui.QLabel(self.uiOptimizationsGroupBox)
        self.uiIdlemaxLabel.setObjectName(_fromUtf8("uiIdlemaxLabel"))
        self.gridLayout_4.addWidget(self.uiIdlemaxLabel, 1, 0, 1, 1)
        self.uiIdlemaxSpinBox = QtGui.QSpinBox(self.uiOptimizationsGroupBox)
        self.uiIdlemaxSpinBox.setMinimum(100)
        self.uiIdlemaxSpinBox.setMaximum(10000)
        self.uiIdlemaxSpinBox.setSingleStep(100)
        self.uiIdlemaxSpinBox.setProperty("value", 500)
        self.uiIdlemaxSpinBox.setObjectName(_fromUtf8("uiIdlemaxSpinBox"))
        self.gridLayout_4.addWidget(self.uiIdlemaxSpinBox, 1, 1, 1, 1)
        self.uiIdlesleepLabel = QtGui.QLabel(self.uiOptimizationsGroupBox)
        self.uiIdlesleepLabel.setObjectName(_fromUtf8("uiIdlesleepLabel"))
        self.gridLayout_4.addWidget(self.uiIdlesleepLabel, 2, 0, 1, 1)
        self.uiMmapCheckBox = QtGui.QCheckBox(self.uiOptimizationsGroupBox)
        self.uiMmapCheckBox.setChecked(True)
        self.uiMmapCheckBox.setObjectName(_fromUtf8("uiMmapCheckBox"))
        self.gridLayout_4.addWidget(self.uiMmapCheckBox, 4, 0, 1, 2)
        self.uiIdlesleepSpinBox = QtGui.QSpinBox(self.uiOptimizationsGroupBox)
        self.uiIdlesleepSpinBox.setMinimum(1)
        self.uiIdlesleepSpinBox.setMaximum(500)
        self.uiIdlesleepSpinBox.setSingleStep(10)
        self.uiIdlesleepSpinBox.setProperty("value", 30)
        self.uiIdlesleepSpinBox.setObjectName(_fromUtf8("uiIdlesleepSpinBox"))
        self.gridLayout_4.addWidget(self.uiIdlesleepSpinBox, 2, 1, 1, 1)
        self.verticalLayout_4.addWidget(self.uiOptimizationsGroupBox)
        spacerItem3 = QtGui.QSpacerItem(304, 251, QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Expanding)
        self.verticalLayout_4.addItem(spacerItem3)
        self.uiTabWidget.addTab(self.uiAdvancedPageWidget, _fromUtf8(""))
        self.uiEnvironmentPageWidget = QtGui.QWidget()
        self.uiEnvironmentPageWidget.setObjectName(_fromUtf8("uiEnvironmentPageWidget"))
        self.verticalLayout_3 = QtGui.QVBoxLayout(self.uiEnvironmentPageWidget)
        self.verticalLayout_3.setObjectName(_fromUtf8("verticalLayout_3"))
        self.uiPowerSuppliesGroupBox = QtGui.QGroupBox(self.uiEnvironmentPageWidget)
        self.uiPowerSuppliesGroupBox.setObjectName(_fromUtf8("uiPowerSuppliesGroupBox"))
        self.gridLayout_7 = QtGui.QGridLayout(self.uiPowerSuppliesGroupBox)
        self.gridLayout_7.setObjectName(_fromUtf8("gridLayout_7"))
        self.uiPowerSupply2Label = QtGui.QLabel(self.uiPowerSuppliesGroupBox)
        self.uiPowerSupply2Label.setObjectName(_fromUtf8("uiPowerSupply2Label"))
        self.gridLayout_7.addWidget(self.uiPowerSupply2Label, 1, 0, 1, 1)
        self.uiPowerSupply1ComboBox = QtGui.QComboBox(self.uiPowerSuppliesGroupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiPowerSupply1ComboBox.sizePolicy().hasHeightForWidth())
        self.uiPowerSupply1ComboBox.setSizePolicy(sizePolicy)
        self.uiPowerSupply1ComboBox.setObjectName(_fromUtf8("uiPowerSupply1ComboBox"))
        self.uiPowerSupply1ComboBox.addItem(_fromUtf8(""))
        self.uiPowerSupply1ComboBox.addItem(_fromUtf8(""))
        self.gridLayout_7.addWidget(self.uiPowerSupply1ComboBox, 0, 1, 1, 1)
        self.uiPowerSupply1Label = QtGui.QLabel(self.uiPowerSuppliesGroupBox)
        self.uiPowerSupply1Label.setObjectName(_fromUtf8("uiPowerSupply1Label"))
        self.gridLayout_7.addWidget(self.uiPowerSupply1Label, 0, 0, 1, 1)
        self.uiPowerSupply2ComboBox = QtGui.QComboBox(self.uiPowerSuppliesGroupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiPowerSupply2ComboBox.sizePolicy().hasHeightForWidth())
        self.uiPowerSupply2ComboBox.setSizePolicy(sizePolicy)
        self.uiPowerSupply2ComboBox.setObjectName(_fromUtf8("uiPowerSupply2ComboBox"))
        self.uiPowerSupply2ComboBox.addItem(_fromUtf8(""))
        self.uiPowerSupply2ComboBox.addItem(_fromUtf8(""))
        self.gridLayout_7.addWidget(self.uiPowerSupply2ComboBox, 1, 1, 1, 1)
        self.verticalLayout_3.addWidget(self.uiPowerSuppliesGroupBox)
        self.uiSensorsGroupBox = QtGui.QGroupBox(self.uiEnvironmentPageWidget)
        self.uiSensorsGroupBox.setObjectName(_fromUtf8("uiSensorsGroupBox"))
        self.gridLayout_3 = QtGui.QGridLayout(self.uiSensorsGroupBox)
        self.gridLayout_3.setObjectName(_fromUtf8("gridLayout_3"))
        self.uiSensor1Label = QtGui.QLabel(self.uiSensorsGroupBox)
        self.uiSensor1Label.setObjectName(_fromUtf8("uiSensor1Label"))
        self.gridLayout_3.addWidget(self.uiSensor1Label, 0, 0, 1, 1)
        self.uiSensor1SpinBox = QtGui.QSpinBox(self.uiSensorsGroupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiSensor1SpinBox.sizePolicy().hasHeightForWidth())
        self.uiSensor1SpinBox.setSizePolicy(sizePolicy)
        self.uiSensor1SpinBox.setMaximum(100)
        self.uiSensor1SpinBox.setObjectName(_fromUtf8("uiSensor1SpinBox"))
        self.gridLayout_3.addWidget(self.uiSensor1SpinBox, 0, 1, 1, 1)
        self.uiSensor2Label = QtGui.QLabel(self.uiSensorsGroupBox)
        self.uiSensor2Label.setObjectName(_fromUtf8("uiSensor2Label"))
        self.gridLayout_3.addWidget(self.uiSensor2Label, 1, 0, 1, 1)
        self.uiSensor2SpinBox = QtGui.QSpinBox(self.uiSensorsGroupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiSensor2SpinBox.sizePolicy().hasHeightForWidth())
        self.uiSensor2SpinBox.setSizePolicy(sizePolicy)
        self.uiSensor2SpinBox.setMaximum(100)
        self.uiSensor2SpinBox.setObjectName(_fromUtf8("uiSensor2SpinBox"))
        self.gridLayout_3.addWidget(self.uiSensor2SpinBox, 1, 1, 1, 1)
        self.uiSensor3Label = QtGui.QLabel(self.uiSensorsGroupBox)
        self.uiSensor3Label.setObjectName(_fromUtf8("uiSensor3Label"))
        self.gridLayout_3.addWidget(self.uiSensor3Label, 2, 0, 1, 1)
        self.uiSensor3SpinBox = QtGui.QSpinBox(self.uiSensorsGroupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiSensor3SpinBox.sizePolicy().hasHeightForWidth())
        self.uiSensor3SpinBox.setSizePolicy(sizePolicy)
        self.uiSensor3SpinBox.setMaximum(100)
        self.uiSensor3SpinBox.setObjectName(_fromUtf8("uiSensor3SpinBox"))
        self.gridLayout_3.addWidget(self.uiSensor3SpinBox, 2, 1, 1, 1)
        self.uiSensor4Label = QtGui.QLabel(self.uiSensorsGroupBox)
        self.uiSensor4Label.setObjectName(_fromUtf8("uiSensor4Label"))
        self.gridLayout_3.addWidget(self.uiSensor4Label, 3, 0, 1, 1)
        self.uiSensor4SpinBox = QtGui.QSpinBox(self.uiSensorsGroupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiSensor4SpinBox.sizePolicy().hasHeightForWidth())
        self.uiSensor4SpinBox.setSizePolicy(sizePolicy)
        self.uiSensor4SpinBox.setMaximum(100)
        self.uiSensor4SpinBox.setObjectName(_fromUtf8("uiSensor4SpinBox"))
        self.gridLayout_3.addWidget(self.uiSensor4SpinBox, 3, 1, 1, 1)
        self.verticalLayout_3.addWidget(self.uiSensorsGroupBox)
        spacerItem4 = QtGui.QSpacerItem(20, 194, QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem4)
        self.uiTabWidget.addTab(self.uiEnvironmentPageWidget, _fromUtf8(""))
        self.vboxlayout.addWidget(self.uiTabWidget)

        self.retranslateUi(iosRouterConfigPageWidget)
        self.uiTabWidget.setCurrentIndex(0)
        self.uiPowerSupply1ComboBox.setCurrentIndex(1)
        self.uiPowerSupply2ComboBox.setCurrentIndex(1)
        QtCore.QMetaObject.connectSlotsByName(iosRouterConfigPageWidget)
        iosRouterConfigPageWidget.setTabOrder(self.uiMidplaneComboBox, self.uiNPEComboBox)
        iosRouterConfigPageWidget.setTabOrder(self.uiNPEComboBox, self.uiRamSpinBox)
        iosRouterConfigPageWidget.setTabOrder(self.uiRamSpinBox, self.uiNvramSpinBox)
        iosRouterConfigPageWidget.setTabOrder(self.uiNvramSpinBox, self.uiDisk0SpinBox)
        iosRouterConfigPageWidget.setTabOrder(self.uiDisk0SpinBox, self.uiDisk1SpinBox)
        iosRouterConfigPageWidget.setTabOrder(self.uiDisk1SpinBox, self.uiSlot0comboBox)
        iosRouterConfigPageWidget.setTabOrder(self.uiSlot0comboBox, self.uiSlot1comboBox)
        iosRouterConfigPageWidget.setTabOrder(self.uiSlot1comboBox, self.uiSlot2comboBox)
        iosRouterConfigPageWidget.setTabOrder(self.uiSlot2comboBox, self.uiSlot3comboBox)
        iosRouterConfigPageWidget.setTabOrder(self.uiSlot3comboBox, self.uiSlot4comboBox)
        iosRouterConfigPageWidget.setTabOrder(self.uiSlot4comboBox, self.uiSlot5comboBox)
        iosRouterConfigPageWidget.setTabOrder(self.uiSlot5comboBox, self.uiSlot6comboBox)
        iosRouterConfigPageWidget.setTabOrder(self.uiSlot6comboBox, self.uiWic0comboBox)
        iosRouterConfigPageWidget.setTabOrder(self.uiWic0comboBox, self.uiWic1comboBox)
        iosRouterConfigPageWidget.setTabOrder(self.uiWic1comboBox, self.uiWic2comboBox)
        iosRouterConfigPageWidget.setTabOrder(self.uiWic2comboBox, self.uiBaseMACLineEdit)
        iosRouterConfigPageWidget.setTabOrder(self.uiBaseMACLineEdit, self.uiExecAreaSpinBox)

    def retranslateUi(self, iosRouterConfigPageWidget):
        iosRouterConfigPageWidget.setWindowTitle(_translate("iosRouterConfigPageWidget", "Dynamips IOS Router configuration", None))
        self.uiNameLabel.setText(_translate("iosRouterConfigPageWidget", "Name:", None))
        self.uiPlatformLabel.setText(_translate("iosRouterConfigPageWidget", "Platform:", None))
        self.uiChassisLabel.setText(_translate("iosRouterConfigPageWidget", "Chassis:", None))
        self.uiIOSImageLabel.setText(_translate("iosRouterConfigPageWidget", "IOS image path:", None))
        self.uiIOSImageToolButton.setText(_translate("iosRouterConfigPageWidget", "&Browse...", None))
        self.uiStartupConfigLabel.setText(_translate("iosRouterConfigPageWidget", "Initial startup-config:", None))
        self.uiStartupConfigToolButton.setText(_translate("iosRouterConfigPageWidget", "&Browse...", None))
        self.uiPrivateConfigLabel.setText(_translate("iosRouterConfigPageWidget", "Initial private-config:", None))
        self.uiPrivateConfigToolButton.setText(_translate("iosRouterConfigPageWidget", "&Browse...", None))
        self.uiConsolePortLabel.setText(_translate("iosRouterConfigPageWidget", "Console port:", None))
        self.uiAuxPortLabel.setText(_translate("iosRouterConfigPageWidget", "Aux port:", None))
        self.uiMidplaneLabel.setText(_translate("iosRouterConfigPageWidget", "Midplane:", None))
        self.uiNPELabel.setText(_translate("iosRouterConfigPageWidget", "NPE:", None))
        self.uiTabWidget.setTabText(self.uiTabWidget.indexOf(self.uiGeneralPageWidget), _translate("iosRouterConfigPageWidget", "General", None))
        self.uiMemoriesGroupBox.setTitle(_translate("iosRouterConfigPageWidget", "Memories", None))
        self.uiRamLabel.setText(_translate("iosRouterConfigPageWidget", "RAM size:", None))
        self.uiRamSpinBox.setSuffix(_translate("iosRouterConfigPageWidget", " MiB", None))
        self.uiNvramLabel.setText(_translate("iosRouterConfigPageWidget", "NVRAM size:", None))
        self.uiNvramSpinBox.setSuffix(_translate("iosRouterConfigPageWidget", " KiB", None))
        self.uiIomemLabel.setText(_translate("iosRouterConfigPageWidget", "I/O memory :", None))
        self.uiIomemSpinBox.setSuffix(_translate("iosRouterConfigPageWidget", " %", None))
        self.uiDisksGroupBox.setTitle(_translate("iosRouterConfigPageWidget", "Disks", None))
        self.uiDisk0Label.setText(_translate("iosRouterConfigPageWidget", "PCMCIA disk0 size:", None))
        self.uiDisk0SpinBox.setSuffix(_translate("iosRouterConfigPageWidget", " MiB", None))
        self.uiDisk1Label.setText(_translate("iosRouterConfigPageWidget", "PCMCIA disk1 size:", None))
        self.uiDisk1SpinBox.setSuffix(_translate("iosRouterConfigPageWidget", " MiB", None))
        self.uiTabWidget.setTabText(self.uiTabWidget.indexOf(self.uiMemoriesPageWidget), _translate("iosRouterConfigPageWidget", "Memories and disks", None))
        self.uiAdaptersGroupBox.setTitle(_translate("iosRouterConfigPageWidget", "Adapters", None))
        self.uiSlot0Label.setText(_translate("iosRouterConfigPageWidget", "slot 0:", None))
        self.uiSlot1Label.setText(_translate("iosRouterConfigPageWidget", "slot 1:", None))
        self.uiSlot2Label.setText(_translate("iosRouterConfigPageWidget", "slot 2:", None))
        self.uiSlot3Label.setText(_translate("iosRouterConfigPageWidget", "slot 3:", None))
        self.uiSlot4Label.setText(_translate("iosRouterConfigPageWidget", "slot 4:", None))
        self.uiSlot5Label.setText(_translate("iosRouterConfigPageWidget", "slot 5:", None))
        self.uiSlot6Label.setText(_translate("iosRouterConfigPageWidget", "slot 6:", None))
        self.uiWicsGroupBox.setTitle(_translate("iosRouterConfigPageWidget", "WICs", None))
        self.uiWic0Label.setText(_translate("iosRouterConfigPageWidget", "wic 0:", None))
        self.uiWic1Label.setText(_translate("iosRouterConfigPageWidget", "wic 1:", None))
        self.uiWic2Label.setText(_translate("iosRouterConfigPageWidget", "wic 2:", None))
        self.uiTabWidget.setTabText(self.uiTabWidget.indexOf(self.uiSlotsPageWidget), _translate("iosRouterConfigPageWidget", "Slots", None))
        self.uiSystemGroupBox.setTitle(_translate("iosRouterConfigPageWidget", "System", None))
        self.label.setText(_translate("iosRouterConfigPageWidget", "System ID:", None))
        self.uiBaseMacLabel.setText(_translate("iosRouterConfigPageWidget", "Base MAC:", None))
        self.uiOptimizationsGroupBox.setTitle(_translate("iosRouterConfigPageWidget", "Optimisations", None))
        self.uiExecAreaLabel.setText(_translate("iosRouterConfigPageWidget", "Exec area:", None))
        self.uiExecAreaSpinBox.setSuffix(_translate("iosRouterConfigPageWidget", " MiB", None))
        self.uiSparseMemoryCheckBox.setText(_translate("iosRouterConfigPageWidget", "Enable sparse memory support", None))
        self.uiIdlepcLabel.setText(_translate("iosRouterConfigPageWidget", "Idle-PC:", None))
        self.uiIdlemaxLabel.setText(_translate("iosRouterConfigPageWidget", "Idlemax:", None))
        self.uiIdlesleepLabel.setText(_translate("iosRouterConfigPageWidget", "Idlesleep:", None))
        self.uiMmapCheckBox.setText(_translate("iosRouterConfigPageWidget", "Enable mmap support", None))
        self.uiIdlesleepSpinBox.setSuffix(_translate("iosRouterConfigPageWidget", " ms", None))
        self.uiTabWidget.setTabText(self.uiTabWidget.indexOf(self.uiAdvancedPageWidget), _translate("iosRouterConfigPageWidget", "Advanced", None))
        self.uiPowerSuppliesGroupBox.setTitle(_translate("iosRouterConfigPageWidget", "Power supplies", None))
        self.uiPowerSupply2Label.setText(_translate("iosRouterConfigPageWidget", "Power supply 2:", None))
        self.uiPowerSupply1ComboBox.setItemText(0, _translate("iosRouterConfigPageWidget", "on", None))
        self.uiPowerSupply1ComboBox.setItemText(1, _translate("iosRouterConfigPageWidget", "off", None))
        self.uiPowerSupply1Label.setText(_translate("iosRouterConfigPageWidget", "Power supply 1:", None))
        self.uiPowerSupply2ComboBox.setItemText(0, _translate("iosRouterConfigPageWidget", "on", None))
        self.uiPowerSupply2ComboBox.setItemText(1, _translate("iosRouterConfigPageWidget", "off", None))
        self.uiSensorsGroupBox.setTitle(_translate("iosRouterConfigPageWidget", "Temperature sensors", None))
        self.uiSensor1Label.setText(_translate("iosRouterConfigPageWidget", "I/0 controller inlet:", None))
        self.uiSensor1SpinBox.setSuffix(_translate("iosRouterConfigPageWidget", " C", None))
        self.uiSensor2Label.setText(_translate("iosRouterConfigPageWidget", "I/0 controller outlet:", None))
        self.uiSensor2SpinBox.setSuffix(_translate("iosRouterConfigPageWidget", " C", None))
        self.uiSensor3Label.setText(_translate("iosRouterConfigPageWidget", "NPE inlet:", None))
        self.uiSensor3SpinBox.setSuffix(_translate("iosRouterConfigPageWidget", " C", None))
        self.uiSensor4Label.setText(_translate("iosRouterConfigPageWidget", "NPE outlet:", None))
        self.uiSensor4SpinBox.setSuffix(_translate("iosRouterConfigPageWidget", " C", None))
        self.uiTabWidget.setTabText(self.uiTabWidget.indexOf(self.uiEnvironmentPageWidget), _translate("iosRouterConfigPageWidget", "Environment", None))

